@@ -36,6 +36,11 @@ if test -n "$CCACHE"; then
     ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/pf/Makefile src/pf/pf.pro
     ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/ipf/Makefile src/ipf/ipf.pro
     ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/ipfw/Makefile src/ipfw/ipfw.pro
+    ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/cisco_lib/Makefile \
+        src/cisco_lib/cisco_lib.pro
+    ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/iosacl/Makefile \
+        src/iosacl/iosacl.pro
+    ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/pix/Makefile src/pix/pix.pro
 
     ${QMAKE} 'QMAKE_CXX=ccache g++'  -o src/parsers/Makefile \
         src/parsers/parsers.pro
@@ -57,6 +62,9 @@ else
     ${QMAKE}  -o src/pf/Makefile        src/pf/pf.pro
     ${QMAKE}  -o src/ipf/Makefile       src/ipf/ipf.pro
     ${QMAKE}  -o src/ipfw/Makefile      src/ipfw/ipfw.pro
+    ${QMAKE}  -o src/cisco_lib/Makefile src/cisco_lib/cisco_lib.pro
+    ${QMAKE}  -o src/iosacl/Makefile    src/iosacl/iosacl.pro
+    ${QMAKE}  -o src/pix/Makefile       src/pix/pix.pro
 
     ${QMAKE}  -o src/parsers/Makefile   src/parsers/parsers.pro
 
