@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: fwbedit.cpp,v 1.25 2006/05/17 02:30:18 vkurland Exp $
+  $Id: fwbedit.cpp,v 1.26 2006/09/09 05:04:57 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -308,7 +308,7 @@ int splitStr(char ch,string s, operands * ops)
 }
 FWObject* createObject(string type,string path)
 {
-    FWObject* obj=objdb->create(type,true);
+    FWObject* obj=objdb->create(type);
     FWObject* parent=getObject(path.c_str());
     if (parent != NULL)
     {
@@ -369,7 +369,7 @@ FWObject* testAndFix(string n,string t,FWObject *root)
     {
         cout << _("Absent ");
         
-        res =objdb->create(t.c_str(),true);
+        res =objdb->create(t.c_str());
         res->setName(n);
         root->add(res);
         cout << _("( Fixed )");
@@ -666,7 +666,7 @@ int main(int argc, char * const *argv)
 
                     if (Interface::isA(target))
                     {
-                        nobj = objdb->create(objtype,true);   
+                        nobj = objdb->create(objtype);   
                         target->add(nobj);
                     }
                 }
@@ -835,7 +835,7 @@ int main(int argc, char * const *argv)
                     FWObject *target = getObject(parent.c_str());
                     if (Host::isA(target) ||  Firewall::isA(target))
                     {
-                        FWObject *nobj = objdb->create(objtype,true);   
+                        FWObject *nobj = objdb->create(objtype);   
                         Interface *o=Interface::cast(nobj);
                         o->setName(name);
                         int sl=atoi(security.c_str());
