@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: fwblookup.cpp,v 1.13 2004/11/26 03:59:26 vkurland Exp $
+  $Id: fwblookup.cpp,v 1.14 2006/03/05 05:53:42 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -83,6 +83,8 @@ static bool       print_addr        = false;  /* -A */
 static bool       print_mgmt_addr   = false;  /* -M */
 static bool       list_children     = false;  /* -l */
 
+FWObjectDatabase       *objdb = NULL;
+
 class UpgradePredicate: public XMLTools::UpgradePredicate
 {
     public:
@@ -102,7 +104,7 @@ void usage(const char *name)
 }
 
 FWObject *find_object(const string &obj_path,
-                      FWObject *root=FWObjectDatabase::db)
+                      FWObject *root=objdb)
 {
     string path=obj_path;
     string::size_type n=path.find("/",0);
@@ -208,12 +210,12 @@ int main(int argc, char * const *argv)
         new Resources(respath+FS_SEPARATOR+"resources.xml");
 
         /* create database */
-        new FWObjectDatabase();
+        objdb = new FWObjectDatabase();
 
         /* load the data file */
         UpgradePredicate upgrade_predicate; 
 
-        FWObjectDatabase::db->load(filename,  &upgrade_predicate, librespath);
+        objdb->load(filename,  &upgrade_predicate, librespath);
         FWObject *obj;
 
         if (strchr(object,'/')!=NULL)
@@ -234,7 +236,7 @@ int main(int argc, char * const *argv)
             }
         } else {
 /* got object ID */
-            obj=FWObjectDatabase::db->getById(object,true);
+            obj=objdb->getById(object,true);
             if (obj==NULL) 
             {
                 SNPRINTF(errstr,sizeof(errstr),_("Object with ID='%s' not found"),object );
