@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: ActionsDialog.cpp,v 1.29 2007/06/14 02:55:29 vkurland Exp $
+  $Id: ActionsDialog.cpp,v 1.30 2007/12/15 20:32:15 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -249,6 +249,7 @@ void ActionsDialog::setRule(PolicyRule *r )
 
     // build a map for combobox so visible combobox items can be localized
     QStringList route_options = getRouteOptions_pf_ipf( platform.c_str() );
+    QStringList route_load_options = getRouteLoadOptions_pf( platform.c_str() );
 
     // iptables
     data.registerOption ( ipt_iif             , ropt , "ipt_iif" );
@@ -265,6 +266,7 @@ void ActionsDialog::setRule(PolicyRule *r )
 
     // pf
     data.registerOption ( pf_fastroute        , ropt , "pf_fastroute"     ); 
+    data.registerOption( pf_route_load_option	      , ropt , "pf_route_load_option", route_load_options );
     data.registerOption ( pf_route_option     , ropt , "pf_route_option",
                           route_options); 
     data.registerOption ( pf_route_opt_if     , ropt , "pf_route_opt_if"  ); 
