@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: AddressRangeDialog.cpp,v 1.22 2006/05/13 06:53:05 vkurland Exp $
+  $Id: AddressRangeDialog.cpp,v 1.23 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -91,6 +91,10 @@ void AddressRangeDialog::changed()
 void AddressRangeDialog::validate(bool *res)
 {
     *res=true;
+
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+
     AddressRange *s = dynamic_cast<AddressRange*>(obj);
     assert(s!=NULL);
     try
@@ -130,13 +134,6 @@ void AddressRangeDialog::libChanged()
 
 void AddressRangeDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
-    bool res=true;
-    validate(&res);
-    if (!res) return;
-
     AddressRange *s = dynamic_cast<AddressRange*>(obj);
     assert(s!=NULL);
 
