@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: DialogFactory.cpp,v 1.14 2006/02/16 07:35:17 vkurland Exp $
+  $Id: DialogFactory.cpp,v 1.15 2007/05/09 04:18:18 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -55,14 +55,16 @@
 #include "ipfwAdvancedDialog.h"
 #include "pfAdvancedDialog.h"
 #include "pixAdvancedDialog.h"
+#include "iosaclAdvancedDialog.h"
 
-#include "pixosAdvancedDialog.h"
 #include "linux24AdvancedDialog.h"
 #include "linksysAdvancedDialog.h"
 #include "freebsdAdvancedDialog.h"
 #include "openbsdAdvancedDialog.h"
 #include "solarisAdvancedDialog.h"
 #include "macosxAdvancedDialog.h"
+#include "pixosAdvancedDialog.h"
+#include "iosAdvancedDialog.h"
 
 #include "RuleOptionsDialog.h"
 #include "RoutingRuleOptionsDialog.h"
@@ -163,6 +165,7 @@ QWidget *DialogFactory::createFWDialog(QWidget *parent,FWObject *o)
     if (dlgname=="ipfw")     return new ipfwAdvancedDialog(parent,o);
     if (dlgname=="pf")       return new pfAdvancedDialog(parent,o);
     if (dlgname=="pix")      return new pixAdvancedDialog(parent,o);
+    if (dlgname=="iosacl")   return new iosaclAdvancedDialog(parent,o);
 
     cerr << "Firewall settings dialog for " << dlgname
          << " is not implemented" << endl;
@@ -180,13 +183,14 @@ QWidget *DialogFactory::createOSDialog(QWidget *parent,FWObject *o)
     string dlgname=os->Resources::getResourceStr("/FWBuilderResources/Target/dialog");
 
 //    string os=o->getStr("host_OS");
-    if (dlgname=="pix_os")    return new pixosAdvancedDialog(parent,o);
     if (dlgname=="linux24")   return new linux24AdvancedDialog(parent,o);
     if (dlgname=="linksys")   return new linksysAdvancedDialog(parent,o);
     if (dlgname=="freebsd")   return new freebsdAdvancedDialog(parent,o);
     if (dlgname=="openbsd")   return new openbsdAdvancedDialog(parent,o);
     if (dlgname=="solaris")   return new solarisAdvancedDialog(parent,o);
     if (dlgname=="macosx")    return new macosxAdvancedDialog(parent,o);
+    if (dlgname=="pix_os")    return new pixosAdvancedDialog(parent,o);
+    if (dlgname=="ios")       return new iosAdvancedDialog(parent,o);
 
     cerr << "OS settings dialog for " << dlgname
          << " is not implemented" << endl;
