@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: FWObjectClipboard.cpp,v 1.7 2006/03/05 04:21:15 vkurland Exp $
+  $Id: FWObjectClipboard.cpp,v 1.9 2006/09/15 05:48:20 vkurland Exp $
 
 
   This program is free software which we release under the GNU General Public
@@ -28,12 +28,13 @@
 #include "config.h"
 #include "global.h"
 
-#include "fwbuilder/FWObjectReference.h"
+#include "fwbuilder/FWReference.h"
 #include "fwbuilder/FWObjectDatabase.h"
 
 #include "FWObjectClipboard.h"
 #include "FWWindow.h"
 
+
 using namespace std;
 using namespace libfwbuilder;
 
@@ -51,32 +52,33 @@ FWObjectClipboard::~FWObjectClipboard()
     obj_clipboard=NULL;
 }
 
-void      FWObjectClipboard::clear()
+void FWObjectClipboard::clear()
 {
-    for (vector<FWObject*>::iterator i=objects.begin(); i!=objects.end(); ++i)
+    for (vector<string>::iterator i=ids.begin(); i!=ids.end(); ++i)
     {
-        FWObject *obj= *i;
-        obj->clearChildren(true);
-        obj->unref();
-        delete obj;
+        FWObject *obj= mw->db()->findInIndex(*i);
+        if (obj) obj->unref();
     }
-    objects.clear();
+    ids.clear();
 }
 
-void      FWObjectClipboard::add(FWObject *_obj)
+void FWObjectClipboard::add(FWObject *_obj)
 {
-    FWObject *obj= mw->db()->create(_obj->getTypeName(),true);
-    obj->ref();
-    *obj = *_obj;
+    if (fwbdebug)
+    {
+	qDebug("FWObjectClipboard::add  adding _obj=%p (id=%s)",
+               _obj,_obj->getId().c_str());
+    }
 
-    objects.push_back(obj);
+    _obj->ref();
+    ids.push_back(_obj->getId());
 }
 
 FWObject* FWObjectClipboard::getObject()
 {
-//    if (obj) 
-//	obj->unref();
-
-    return objects.back();
+    if (ids.size()>0)
+        return mw->db()->findInIndex( ids.back() );
+    else
+        return NULL;
 }
 
