@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWObjectPropertiesFactory.cpp,v 1.51 2007/02/04 03:58:59 vkurland Exp $
+  $Id: FWObjectPropertiesFactory.cpp,v 1.53 2007/05/23 03:05:50 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -25,6 +25,7 @@
 
 #include "config.h"
 #include "global.h"
+#include "utils_no_qt.h"
 #include "utils.h"
 #include "definitions.h"
 
@@ -397,6 +398,8 @@ QString FWObjectPropertiesFactory::getObjectPropertiesDetailed(FWObject *obj,
             {
                 if (Interface::constcast(obj)->isExt())        q=q+" ext";
             }
+
+            if (Interface::constcast(obj)->isUnprotected())    q=q+" unp";
             
             if (q!="") str += " (" + q + ")";
             str += "<br>\n";
