@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.cpp,v 1.220 2007/07/07 05:39:33 vkurland Exp $
+  $Id: FWWindow.cpp,v 1.221 2008/03/10 03:42:20 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -1188,8 +1188,9 @@ bool FWWindow::checkin(bool unlock)
     if (systemFile || rcs==NULL || !rcs->isCheckedOut() || rcs->isTemp())
         return true;
 
-    if (rcs->isDiff()) // if the file hasn't changed, do not need to ask for the comment
+    if (rcs->isDiff()) 
     {
+        // if the file hasn't changed, do not need to ask for the comment
         if ( ! st->getRCSLogState())
         {
             RCSFileSaveDialog_q fsd(this);
