@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindowPrint.cpp,v 1.24 2007/06/21 05:43:26 vkurland Exp $
+  $Id: FWWindowPrint.cpp,v 1.25 2008/05/09 04:29:28 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -296,6 +296,8 @@ void printFirewall(FWObject *fw,
     ruleView->setHScrollBarMode(QScrollView::AlwaysOff);
     ruleView->setVScrollBarMode(QScrollView::AlwaysOff);
 
+    ruleView->setMaximumHeight(pr.getPageHeight());
+
     if (fwbdebug) qDebug("Contents: %dx%d",
                          ruleView->contentsWidth(),ruleView->contentsHeight());
     if (fwbdebug) qDebug("Visible: %dx%d",
@@ -416,12 +418,7 @@ void FWWindow::filePrint()
     int pageHeight = 0;
     bool  fullPage = false;
 
-    float margin;
-#if defined(Q_OS_MACX) || defined(Q_OS_WIN32)
-    margin=1.5;
-#else
-    margin=0;
-#endif
+    float margin = 0;
     int   resolution = 150;
     bool  printHeader = true;
     bool  printLegend = true;
