@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IOSImporter.cpp,v 1.10 2007/05/29 06:01:24 vkurland Exp $
+  $Id: IOSImporter.cpp,v 1.11 2007/08/06 07:07:22 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -279,10 +279,10 @@ std::pair<int,int> IOSImporter::convertPortSpec(const std::string &port_op,
     std::string s1,s2;
     std::string portop = strip(port_op);
     std::string portspec = strip(port_spec);
-    std::ostringstream dbg;
 
-    dbg << "Convert TCP/UDP port spec: port_op=" << port_op
-        << " port_spec=" << port_spec << std::endl;
+    if (fwbdebug)
+        qDebug(QString("Convert TCP/UDP port spec: port_op=%1 port_spec=%2").
+               arg(port_op).arg(port_spec));
 
     if (portop=="" && portspec=="") return std::pair<int,int>(0, 0);
 
@@ -311,7 +311,6 @@ std::pair<int,int> IOSImporter::convertPortSpec(const std::string &port_op,
         ;
     }
 
-    debug_output += dbg.str();
     return std::pair<int,int>(range_start, range_end);
 }
 
@@ -385,13 +384,7 @@ Firewall* IOSImporter::finalize()
     // UnidirectionalRuleSet into one RuleSet object. Attach this
     // object to the firewall.
 
-    // Add progress print to debug_output instead of using qDebug
-    // so it can be used for unit tests
-
-    std::ostringstream dbg;
-
-    dbg << std::endl;
-    dbg << "******************************** FINALIZE:" << std::endl;
+    if (fwbdebug) qDebug("IPTImporter::finalize()");
 
     if (haveFirewallObject())
     {
@@ -404,20 +397,27 @@ Firewall* IOSImporter::finalize()
 
         if (all_rulesets.size()!=0)
         {
-            dbg << "Setting interface and direction for all rules" << std::endl;
-            dbg << "all_rulesets.size()=" << all_rulesets.size() << std::endl;
+            if (fwbdebug)
+            {
+                qDebug("Setting interface and direction for all rules");
+                qDebug(QString("all_rulesets.size()=%1").
+                       arg(all_rulesets.size()));
+            }
 
             std::map<const std::string,UnidirectionalRuleSet*>::iterator i;
             for (i=all_rulesets.begin(); i!=all_rulesets.end(); ++i)
             {
                 UnidirectionalRuleSet *irs = (*i).second;
 
-                dbg << "  irs->name="
-                    << irs->name.c_str() << std::endl;
-                dbg << "  irs->intf_dir.size()="
-                    << irs->intf_dir.size() << std::endl;
-                dbg << "  irs->ruleset->size()="
-                    << irs->ruleset->size() << std::endl;
+                if (fwbdebug)
+                {
+                    qDebug(QString("  irs->name=%1").
+                           arg(irs->name.c_str()));
+                    qDebug(QString("  irs->intf_dir.size()=%1").
+                           arg(irs->intf_dir.size()));
+                    qDebug(QString("  irs->ruleset->size()=%1").
+                           arg(irs->ruleset->size()));
+                }
 
                 // optimization: If we have several interfaces for
                 // the ruleset, create a group
@@ -499,8 +499,9 @@ Firewall* IOSImporter::finalize()
                         // not all access lists are associated with interfaces
                         if (intf!=NULL)
                         {
-                            dbg << "    interface="
-                                << intf->getName() << std::endl;
+                            if (fwbdebug)
+                                qDebug(QString("    interface=%1").
+                                       arg(intf->getName().c_str()));
                             std::for_each(irs->ruleset->begin(),
                                           irs->ruleset->end(), 
                                           merge_rule(irs->name,
@@ -511,7 +512,7 @@ Firewall* IOSImporter::finalize()
                         }
                     }
                 }
-                dbg << "ruleset done" << std::endl;;
+                qDebug("ruleset done");
 
                 // call clearChidren() not recursive because children objects
                 // of all rules should not be deleted
@@ -521,8 +522,6 @@ Firewall* IOSImporter::finalize()
             }
         }
 
-        debug_output += dbg.str();
-
         return getFirewallObject();
     }
     else
