@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPTImporter.cpp,v 1.9 2007/08/06 07:07:22 vkurland Exp $
+  $Id: IPTImporter.cpp,v 1.11 2008/05/05 16:09:38 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -458,7 +458,20 @@ void IPTImporter::pushPolicyRule()
     {
         action = PolicyRule::Tag;
         last_mark_rule = rule;
-        ropt->setStr("tagvalue", action_params["set_mark"]);
+        std::string mark_code = action_params["set_mark"];
+        std::istringstream str(mark_code);
+        int m_code = 0;
+
+        // check if the code is in hex
+        if (mark_code.find("0x")==0)
+        {
+            char c;
+            str >> c >> c >> std::hex >> m_code;
+        } else
+        {
+            str >> m_code;
+        }
+        ropt->setInt("tagvalue", m_code);
 //        if (current_chain=="PREROUTING")
 //            ropt->setBool("ipt_mark_prerouting",true);
     }
@@ -479,11 +492,22 @@ void IPTImporter::pushPolicyRule()
         ropt->setBool("ipt_continue", !action_params["route_continue"].empty());
         ropt->setBool("ipt_tee",      !action_params["route_tee"].empty());
     }
+
     if (target=="RETURN")
     {
         action = PolicyRule::Continue;
     }
 
+    if (target=="TCPMSS" && action_params["clamp-mss-to-pmtu"]=="--clamp-mss-to-pmtu")
+    {
+        fwopt->setBool("clamp_mss_to_mtu", true);
+        skip_rule = true;
+        *Importer::logger
+            << "Using automatic rule controlled by option "
+            << "Clamp MSS to MTU"
+            << "\n";
+    }
+
     if (action==PolicyRule::Unknown)
     {
         // unknown target, consider it a branch
