@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: InterfaceDialog.cpp,v 1.29 2007/04/14 00:18:43 vkurland Exp $
+  $Id: InterfaceDialog.cpp,v 1.30 2007/05/10 01:35:52 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -107,14 +107,17 @@ void InterfaceDialog::loadFWObject(FWObject *o)
         netzoneLabel->hide();
     }
 
-    bool supports_security_levels=false;
-    bool supports_network_zones  =false;
+    bool supports_security_levels = false;
+    bool supports_network_zones   = false;
+    bool supports_unprotected     = false;
 
     try  {
-        supports_security_levels=
+        supports_security_levels =
             Resources::getTargetCapabilityBool(f->getStr("platform"), "security_levels");
-        supports_network_zones=
+        supports_network_zones =
             Resources::getTargetCapabilityBool(f->getStr("platform"), "network_zones");
+        supports_unprotected =
+            Resources::getTargetCapabilityBool(f->getStr("platform"), "unprotected_interfaces");
     } catch (FWException &ex)  { }
 
 /* if parent is a firewall, it is more complex ... */
@@ -134,6 +137,15 @@ void InterfaceDialog::loadFWObject(FWObject *o)
             ext->setChecked( obj->getInt("security_level")==0 );
         }
 
+        if (supports_unprotected)
+        {
+            unprotected->show();
+            unprotected->setChecked( obj->getBool("unprotected") );
+        } else
+        {
+            unprotected->hide();
+        }
+
         if (supports_network_zones)
         {
             netzone->show();
@@ -244,6 +256,9 @@ void InterfaceDialog::loadFWObject(FWObject *o)
     management->setEnabled(!o->isReadOnly());
     setDisabledPalette(management);
 
+    unprotected->setEnabled(!o->isReadOnly());
+    setDisabledPalette(unprotected);
+
     ext->setEnabled(!o->isReadOnly());
     setDisabledPalette(ext);
 
@@ -299,14 +314,17 @@ void InterfaceDialog::applyChanges()
     s->setBridgePort( bridgeport->isChecked() );
 
     FWObject *f = obj->getParent();
-    bool supports_security_levels =false;
-    bool supports_network_zones   =false;
+    bool supports_security_levels = false;
+    bool supports_network_zones   = false;
+    bool supports_unprotected     = false;
 
     try  {
         supports_security_levels=
             Resources::getTargetCapabilityBool(f->getStr("platform"), "security_levels");
         supports_network_zones=
             Resources::getTargetCapabilityBool(f->getStr("platform"), "network_zones");
+        supports_unprotected =
+            Resources::getTargetCapabilityBool(f->getStr("platform"), "unprotected_interfaces");
     } catch (FWException &ex)  { }
 
 
@@ -317,11 +335,15 @@ void InterfaceDialog::applyChanges()
         else
             obj->setInt("security_level", (ext->isChecked()) ? 0 : 100 );
 
+        if (supports_unprotected)
+            obj->setBool("unprotected",  unprotected->isChecked() );
+
         if (supports_network_zones)
             obj->setStr("network_zone",
                         netzoneObjectNos[ netzone->currentItem() ].latin1() );
 
         s->setManagement( management->isChecked() );
+
     }
 
     om->updateObjName(obj,
