@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: LibExportDialog.h,v 1.4 2004/06/30 05:43:35 vkurland Exp $
+  $Id: LibExportDialog.h,v 1.5 2006/07/13 04:59:22 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,9 +29,10 @@
 
 #include "libexport_q.h"
 
-#include <qfiledialog.h>
 #include <qlistview.h>
 
+
+
 #include <map>
 #include <list>
 
@@ -42,30 +43,19 @@ namespace libfwbuilder {
     class FWReference;
 };
 
-class LibExportDialog : public QFileDialog {
+class LibExportDialog : public  LibExport_q{
 
     Q_OBJECT
 
-    LibExport_q  *le;
-
-    std::map<int, libfwbuilder::FWObject*>   mapOfLibs;
 
     void init();
 
-    void findExternalRefs(libfwbuilder::FWObject *lib,
-                          libfwbuilder::FWObject *root,
-                          std::list<libfwbuilder::FWReference*> &extRefs);
 
  public:
-
-    LibExportDialog(const QString& dirName, const QString& filter = QString::null,
-                    QWidget* parent=0, const char* name=0, bool modal = FALSE );
+    std::map<int, libfwbuilder::FWObject*>   mapOfLibs;
     LibExportDialog(QWidget* parent=0, const char* name=0, bool modal = FALSE );
-
  protected slots:
 
-     virtual void accept();
-     virtual void libSelected(QListBoxItem *itm);
 };
 
 #endif
