@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: NetworkDialog.cpp,v 1.21 2006/05/13 06:53:05 vkurland Exp $
+  $Id: NetworkDialog.cpp,v 1.22 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -92,6 +92,10 @@ void NetworkDialog::changed()
 void NetworkDialog::validate(bool *res)
 {
     *res=true;
+
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+
     Network *s = dynamic_cast<Network*>(obj);
     assert(s!=NULL);
     try
@@ -130,13 +134,6 @@ void NetworkDialog::libChanged()
 
 void NetworkDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
-    bool res=true;
-    validate( &res );
-    if (!res) return;
-
     Network *s = dynamic_cast<Network*>(obj);
     assert(s!=NULL);
 
