@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectIconView.cpp,v 1.9 2005/09/07 16:40:50 vkurland Exp $
+  $Id: ObjectIconView.cpp,v 1.10 2006/10/22 04:39:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,6 +38,7 @@
 
 #include <qdragobject.h>
 #include <qiconview.h>
+#include <qpixmapcache.h>
 
 #include <iostream>
 
@@ -61,13 +62,21 @@ QDragObject* ObjectIconView::dragObject()
     assert(oivi!=NULL);
 
     FWObject *obj = oivi->getFWObject();
-    QString icn_filename =
+    QString icn =
         Resources::global_res->getObjResourceStr(obj, "icon-ref").c_str();
     list<FWObject*> dragobj;
     dragobj.push_back(obj);
 
     FWObjectDrag    *drag = new FWObjectDrag(dragobj, this);
-    QPixmap          pm   = QPixmap::fromMimeSource( icn_filename );
+    //QPixmap          pm   = QPixmap::fromMimeSource( icn_filename );
+
+    QPixmap pm;
+    if ( ! QPixmapCache::find( icn, pm) )
+    {
+        pm = QPixmap::fromMimeSource( icn );
+        QPixmapCache::insert( icn, pm);
+    }
+
     drag->setPixmap( pm,
                      QPoint( pm.rect().width() / 2,
                              pm.rect().height() / 2 ) );
