@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectListView.cpp,v 1.11 2006/06/01 06:26:53 vkurland Exp $
+  $Id: ObjectListView.cpp,v 1.12 2006/10/22 04:39:36 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -39,6 +39,7 @@
 
 #include <qdragobject.h>
 #include <qlistview.h>
+#include <qpixmapcache.h>
 
 #include <iostream>
 
@@ -68,14 +69,22 @@ QDragObject* ObjectListView::dragObject()
     assert(otvi!=NULL);
 
     FWObject *obj = otvi->getFWObject();
-    QString icn_filename =
+    QString icn =
         Resources::global_res->getObjResourceStr(obj, "icon-ref").c_str();
 
     list<FWObject*> dragobj;
     dragobj.push_back(obj);
 
     FWObjectDrag    *drag = new FWObjectDrag(dragobj, this);
-    QPixmap          pm   = QPixmap::fromMimeSource( icn_filename );
+    //QPixmap          pm   = QPixmap::fromMimeSource( icn_filename );
+
+    QPixmap pm;
+    if ( ! QPixmapCache::find( icn, pm) )
+    {
+        pm = QPixmap::fromMimeSource( icn );
+        QPixmapCache::insert( icn, pm);
+    }
+    
     drag->setPixmap( pm,
                      QPoint( pm.rect().width() / 2,
                              pm.rect().height() / 2 ) );
