@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectTreeView.cpp,v 1.42 2007/03/22 15:09:02 vkurland Exp $
+  $Id: ObjectTreeView.cpp,v 1.43 2007/07/07 05:39:34 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -775,18 +775,18 @@ void ObjectTreeView::setLockFlags()
         {
             QListViewItem *itm= it.current();
             ObjectTreeViewItem *otvi=dynamic_cast<ObjectTreeViewItem*>(itm);
-            if (otvi->getFWObject()->getBool("ro")) 
+
+            FWObject *lib = otvi->getFWObject()->getLibrary();
+            // these lbraries are locked anyway, do not let the user
+            // lock objects inside because they won't be able to unlock them.
+            if (lib->getId()!=STANDARD_LIB && lib->getId()!=TEMPLATE_LIB)
             {
-                Unlockable=true;
-            }
-            else
-            {
-                Lockable=true;
+                if (otvi->getFWObject()->getBool("ro"))  Unlockable=true;
+                else                                     Lockable=true;
             }
         }
         ++it;
     }
-    
 }
 
 bool ObjectTreeView::isSelected(FWObject* obj)
