@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PrefsDialog.cpp,v 1.29 2007/02/04 04:20:26 vkurland Exp $
+  $Id: PrefsDialog.cpp,v 1.30 2008/02/11 02:15:09 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -82,7 +82,9 @@ void PrefsDialog::setButtonColor(QPushButton *btn,const QString &colorCode)
 PrefsDialog::PrefsDialog(QWidget *parent) : prefsDialog_q(parent)
 {
     wDir->setText( st->getWDir() );
-    startupAction->setCurrentItem( st->getStartupAction() );
+    int sa_itm = st->getStartupAction();
+    if (sa_itm < 0 || sa_itm > 1) sa_itm = 0;
+    startupAction->setCurrentItem( sa_itm );
     expandTree->setChecked( st->getExpandTree() );
 //    mergeLibs->setChecked( st->getMergeLibs() );
 
