@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCS.cpp,v 1.62 2006/10/21 06:53:25 vkurland Exp $
+  $Id: RCS.cpp,v 1.64 2008/03/10 03:42:20 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -219,6 +219,10 @@ RCSEnvFix::RCSEnvFix()
 
     env.push_back( QString("USER=")+uname);
     env.push_back( QString("LOGNAME=")+uname);
+    if (getenv("TMP")!=NULL)
+        env.push_back( QString("TMP=") + getenv("TMP"));
+    if (getenv("TEMP")!=NULL)
+        env.push_back( QString("TEMP=") + getenv("TEMP"));
 }
 
 QStringList* RCSEnvFix::getEnv()
@@ -541,6 +545,9 @@ void RCS::add() throw(libfwbuilder::FWException)
             stdoutBuffer="";
             stderrBuffer="";
 
+            if (fwbdebug) qDebug("starting ci with environment '%s'",
+                                 rcsenvfix->getEnv()->join("\n").ascii());
+
             if (proc->start( rcsenvfix->getEnv() ) )
             {
                 while (proc->isRunning()) ; // cxx_sleep(1);
