@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland vadim@fwbuilder.org
 
-  $Id: RCSFilePreview.cpp,v 1.16 2004/12/20 08:04:06 vkurland Exp $
+  $Id: RCSFilePreview.cpp,v 1.18 2006/10/21 15:12:11 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -68,6 +68,8 @@ int RCSViewItem::compare(QListViewItem *itm, int col, bool ascending) const
 RCSFilePreview::RCSFilePreview( RCSFileDialog *parent )
     : RCSFilePreview_q(parent), QFilePreview()
 {
+    if (fwbdebug) qDebug("RCSFilePreview: constructor");
+
     dialog=parent;
 
 //    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, false ) );
@@ -93,18 +95,21 @@ RCSFilePreview::RCSFilePreview( RCSFileDialog *parent )
     RCSTreeView->setResizeMode( QListView::LastColumn );
 //    RCSTreeView->setHScrollBarMode( QScrollView::AlwaysOff );
 
+    if (fwbdebug) qDebug("RCSFilePreview: constructor done");
+
     rcs=NULL;
 }
 
 RCSFilePreview::~RCSFilePreview()
 {
+    if (fwbdebug) qDebug("~RCSFilePreview()  rcs=%p",rcs);
 //    if (rcs!=NULL) delete rcs;
 }
 
 void RCSFilePreview::openReadOnly()
 {
     if (rcs!=NULL) rcs->setRO(true);
-    dialog->openFile();
+    dialog->openFileRO();
 }
 
 void RCSFilePreview::selectedRevision(QListViewItem *itm)
@@ -113,10 +118,14 @@ void RCSFilePreview::selectedRevision(QListViewItem *itm)
     assert(rcs!=NULL);
     rcs->setSelectedRev(rev);
     comment->setText( rcsComments[rev] );
+    if (fwbdebug) qDebug("RCSFilePreview::selectedRevision : %s",rev.ascii());
 }
 
 void RCSFilePreview::showFileRLog( const QString &filename )
 {
+    if (fwbdebug) qDebug("RCSFilePreview::showFileRLog filename=%s rcs=%p",
+                         filename.ascii(),rcs);
+
     RCSTreeView->clear();
 
     if (rcs!=NULL) delete rcs;
@@ -127,6 +136,7 @@ void RCSFilePreview::showFileRLog( const QString &filename )
         QListViewItem *itm=new QListViewItem(RCSTreeView);
         itm->setText( 0, tr("File is not in RCS") );
 //        addToRCS->setEnabled(true);
+        comment->setText("");
 
         return;
     }
@@ -173,6 +183,9 @@ void RCSFilePreview::showFileRLog( const QString &filename )
 
 void RCSFilePreview::previewUrl( const QUrl &u )
 {
+    if (fwbdebug) qDebug("RCSFilePreview::previewUrl u=%s",
+                         u.toString().ascii());
+
     QString f=u.path(true);
 
 /* if file name ends with '/', it is a directory - no need to check
@@ -191,8 +204,12 @@ void RCSFilePreview::previewUrl( const QUrl &u )
 
 RCS* RCSFilePreview::getSelectedRev()
 {
-    if (rcs!=NULL) return rcs;
-    return new RCS(current_file);
+    if (fwbdebug) qDebug("RCSFilePreview::getSelectedRev rcs=%p",rcs);
+
+    return rcs;
+
+//    if (rcs!=NULL) return rcs;
+//    return new RCS(current_file);
 }
 
 
