@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: RuleOptionsDialog.cpp,v 1.24 2007/07/14 21:08:42 vkurland Exp $
+  $Id: RuleOptionsDialog.cpp,v 1.26 2008/05/06 03:18:49 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -104,6 +104,8 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
     ipt_limitSuffix->clear();
     ipt_limitSuffix->insertStringList(getScreenNames(limitSuffixes));
     
+    ipt_hashlimit_suffix->clear();
+    ipt_hashlimit_suffix->insertStringList(getScreenNames(limitSuffixes));
     
     data.clear();
     
@@ -155,17 +157,15 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
         data.registerOption( pf_max_src_states   , ropt,  "pf_max_src_states" );
 
         data.registerOption( pf_max_src_conn     , ropt,  "pf_max_src_conn" );
-        data.registerOption( pf_max_src_conn_overload_table     ,
-                             ropt,  "pf_max_src_conn_overload_table" );
-        data.registerOption( pf_max_src_conn_flush, ropt,  "pf_max_src_conn_flush" );
-        data.registerOption( pf_max_src_conn_global, ropt, "pf_max_src_conn_global" );
+        data.registerOption( pf_overload_table   , ropt,
+                             "pf_max_src_conn_overload_table" );
+        data.registerOption( pf_flush, ropt,  "pf_max_src_conn_flush" );
+        data.registerOption( pf_global, ropt, "pf_max_src_conn_global" );
 
-        data.registerOption( pf_max_src_conn_rate_num     , ropt,  "pf_max_src_conn_rate_num" );
-        data.registerOption( pf_max_src_conn_rate_seconds , ropt,  "pf_max_src_conn_rate_seconds" );
-        data.registerOption( pf_max_src_conn_rate_overload_table     ,
-                             ropt,  "pf_max_src_conn_rate_overload_table" );
-        data.registerOption( pf_max_src_conn_rate_flush, ropt,  "pf_max_src_conn_rate_flush" );
-        data.registerOption( pf_max_src_conn_rate_global, ropt, "pf_max_src_conn_rate_global" );
+        data.registerOption( pf_max_src_conn_rate_num     , ropt,
+                             "pf_max_src_conn_rate_num" );
+        data.registerOption( pf_max_src_conn_rate_seconds , ropt,
+                             "pf_max_src_conn_rate_seconds" );
     }
 
     if (platform=="ipfw")
@@ -204,7 +204,7 @@ void RuleOptionsDialog::loadFWObject(FWObject *o)
     //apply->setEnabled( false );
     init=false;
 }
-    
+
 void RuleOptionsDialog::changed()
 {
     //apply->setEnabled( true );
@@ -212,13 +212,13 @@ void RuleOptionsDialog::changed()
     pf_max_src_nodes->setEnabled( pf_source_tracking->isChecked() );
     pf_max_src_states->setEnabled( pf_source_tracking->isChecked() );
 
-    pf_max_src_conn_overload_table->setEnabled( pf_max_src_conn->value()>0 );
-    pf_max_src_conn_flush->setEnabled( pf_max_src_conn->value()>0 );
-    pf_max_src_conn_global->setEnabled( pf_max_src_conn->value()>0 );
+    bool enable_overload_options = (pf_max_src_conn->value()>0 || (
+                                    pf_max_src_conn_rate_num->value()>0 &&
+                                    pf_max_src_conn_rate_seconds->value()>0));
 
-    pf_max_src_conn_rate_overload_table->setEnabled( pf_max_src_conn_rate_num->value()>0 && pf_max_src_conn_rate_seconds->value()>0);
-    pf_max_src_conn_rate_flush->setEnabled( pf_max_src_conn_rate_num->value()>0 && pf_max_src_conn_rate_seconds->value()>0 );
-    pf_max_src_conn_rate_global->setEnabled( pf_max_src_conn_rate_num->value()>0 && pf_max_src_conn_rate_seconds->value()>0 );
+    pf_overload_table->setEnabled(enable_overload_options);
+    pf_flush->setEnabled(enable_overload_options);
+    pf_global->setEnabled(enable_overload_options);
 
     emit changed_sign();
 }
