@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.cpp,v 1.27 2007/07/13 05:32:55 vkurland Exp $
+  $Id: SSHSession.cpp,v 1.28 2007/12/15 23:19:04 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -194,7 +194,9 @@ void SSHSession::startSession()
 
 SSHSession::~SSHSession()
 {
+    if (fwbdebug) qDebug("SSHSession::destructor");
     terminate();
+    if (fwbdebug) qDebug("SSHSession::destructor done");
 }
 
 /*
