@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.h,v 1.16 2006/09/17 05:15:50 vkurland Exp $
+  $Id: SSHSession.h,v 1.18 2007/07/13 05:32:55 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -71,6 +71,8 @@ class SSHSession : public QObject {
     enum State { NONE,
                  LOGGEDIN,
                  WAITING_FOR_ENABLE,
+                 PRE_CONFIG_COMMANDS,
+                 SCHEDULE_RELOAD_DIALOG,
                  ENABLE,
                  CONFIG,
                  COMMAND_SENT,
@@ -138,7 +140,9 @@ class SSHSession : public QObject {
     static char* newKeyOpenSSH;
     static char* newKeyPlink;
     static char* newKeyVsh;
-    static char* fingerprintPrompt;
+    static char* newKeySSHComm;
+    static char* fingerprintPrompt1;
+    static char* fingerprintPrompt2;
     
     QString newKeyMsg;
 
@@ -159,6 +163,7 @@ public:
 	       const std::list<std::string> &in);
     virtual ~SSHSession();
 
+    virtual bool checkForErrors();
     virtual void stateMachine();
 
     void startSession();
@@ -186,7 +191,9 @@ public:
     bool getErrorStatus() { return error; }
 
     void sessionComplete(bool err);
- 
+
+    QString findKeyFingerprint(QString &buffer);
+
 public slots:
      void readFromStdout();
      void readFromStderr();
