@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHUnx.cpp,v 1.24 2007/07/13 05:32:55 vkurland Exp $
+  $Id: SSHUnx.cpp,v 1.25 2007/12/15 23:19:04 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -71,6 +71,7 @@ SSHUnx::SSHUnx(QWidget *_par,
 
     iptables_errors.push_back("'iptables --help' for more information.");
     iptables_errors.push_back("'iptables-restore --help' for more information.");
+    iptables_errors.push_back("iptables-restore: line .* failed");
 }
 
 SSHUnx::~SSHUnx()
@@ -87,7 +88,7 @@ bool SSHUnx::checkForErrors(QStringList *errptr)
         if (fwbdebug)
             qDebug(QString("SSHUnx::stateMachine:  error='%1'").arg(*i));
 
-        if ( stdoutBuffer.findRev(*i,-1)!=-1 )
+        if ( stdoutBuffer.findRev(QRegExp(*i),-1)!=-1 )
         {
             if (fwbdebug)
                 qDebug("SSHUnx::stateMachine: MATCH. Error detected.");
