@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: TimeDialog.h,v 1.5 2006/05/13 06:53:05 vkurland Exp $
+  $Id: TimeDialog.h,v 1.6 2007/03/14 05:08:11 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,6 +40,8 @@ class TimeDialog : public TimeDialog_q
     libfwbuilder::FWObject *obj;
     bool init;
 
+    void enableAllWidgets();
+    
  public:
     TimeDialog(QWidget *parent) : TimeDialog_q(parent) { obj=NULL; }
     
@@ -47,6 +49,7 @@ public slots:
     virtual void changed();
     virtual void libChanged();
     virtual void applyChanges();
+    virtual void useStartOrEndDate();
     virtual void discardChanges();
     virtual void loadFWObject(libfwbuilder::FWObject *obj);
     virtual void validate(bool*);
