@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: debugDialog.cpp,v 1.10 2006/03/05 04:21:15 vkurland Exp $
+  $Id: debugDialog.cpp,v 1.11 2006/10/22 05:24:28 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -35,6 +35,7 @@
 #include <qtextbrowser.h>
 #include <qtextcodec.h>
 #include <qglobal.h>
+#include <qpixmapcache.h>
 
 #include "fwbuilder/Constants.h"
 #include "fwbuilder/FWObjectDatabase.h"
@@ -90,12 +91,14 @@ debugDialog::debugDialog(QWidget *parent) : debugDialog_q(parent)
 #endif
     debugText->append( "\n" );
 
-    debugText->append( QString("  FWObjectDatabase index statistics:") );
+    debugText->append( QString("FWObjectDatabase index statistics:") );
     
     int s,h,m;
     mw->db()->getIndexStats(s,h,m);
-    debugText->append( QString("     index size: %1 records").arg(s) );
-    debugText->append( QString("     hits: %1").arg(h) );
-    debugText->append( QString("     misses: %1").arg(m) );
+    debugText->append( QString("  index size: %1 records").arg(s) );
+    debugText->append( QString("  hits: %1").arg(h) );
+    debugText->append( QString("  misses: %1").arg(m) );
+    debugText->append( "\n" );
 
+    debugText->append( QString("QPixmapCache limit: %1 kb").arg(QPixmapCache::cacheLimit()));
 }
