@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: execDialog.cpp,v 1.9 2005/04/17 21:58:55 vkurland Exp $
+  $Id: execDialog.cpp,v 1.10 2006/02/18 05:26:30 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -24,6 +24,7 @@
 */
 
 #include "config.h"
+#include "global.h"
 
 #include "execDialog.h"
 
@@ -32,6 +33,10 @@
 #include <qtimer.h>
 #include <qtextbrowser.h>
 #include <qpushbutton.h>
+#include <qfile.h>
+#include <qfiledialog.h>
+
+#include "FWBSettings.h"
 
 #if defined(Q_OS_WIN32)
 #  include <stdio.h>
@@ -61,6 +66,7 @@ execDialog::execDialog(QWidget *parent,const QStringList &args, const QString &c
     proc.setArguments( args );
 
     stopButton->hide();
+    saveLogButton->hide();
 }
 
 void execDialog::readFromStdout()
@@ -79,6 +85,7 @@ void execDialog::stopProcess()
 void execDialog::processExited()
 {
     stopButton->hide();
+    saveLogButton->show();
     buttonOk->setEnabled( true );
     buttonOk->setFocus();
     res=proc.exitStatus();
@@ -94,9 +101,39 @@ int execDialog::run()
         output->append( tr("Error: Failed to start program") );
         return exec();
     }
-    stopButton->show();
+    saveLogButton->hide();
+    stopButton->show();    
     stopButton->setFocus();
     buttonOk->setEnabled( false );
     exec();
     return res;
 }
+void execDialog::saveLog()
+{
+    QString dir;
+    dir=st->getWDir();
+    if (dir.isEmpty())  dir=st->getOpenFileDir();
+    if (dir.isEmpty())  dir="~";
+    
+    QString s = QFileDialog::getSaveFileName(
+                    dir,
+                    "Text file (*.txt)",
+                    this,
+                    "save file dialog",
+                    "Choose a file" );
+    
+    
+    if (!s.isEmpty())
+    {
+        if (s.findRev(".txt",-1,false)==-1)
+        {
+            s+=".txt";
+        }
+        QFile f(s);
+        if (f.open(IO_WriteOnly))
+        {
+            QTextStream (&f) << output->text();
+            f.close();
+        }
+    }    
+}
