@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: findDialog.cpp,v 1.11 2005/04/24 06:51:01 vkurland Exp $
+  $Id: findDialog.cpp,v 1.13 2006/06/13 06:54:24 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -281,7 +281,7 @@ loop:
 
     if (FWReference::cast(o)!=NULL && RuleElement::cast(o->getParent())!=NULL)
     {
-        mw->ensureObjectVisible( FWReference::cast(o) );
+        mw->ensureObjectVisibleInRules( FWReference::cast(o) );
         QTimer::singleShot(200, this, SLOT(makeActive()) );
         return;
     } 
@@ -290,7 +290,7 @@ loop:
         !FWBTree::isSystem(o->getParent()))
     {
         om->openObject( o->getParent() );
-        om->edit( o->getParent() );
+        om->editObject( o->getParent() );
         QTimer::singleShot(200, this, SLOT(makeActive()) );
         return;
     }
@@ -302,7 +302,7 @@ loop:
     }
 
     om->openObject( o );
-    om->edit( o );
+    om->editObject( o );
 
     QTimer::singleShot(200, this, SLOT(makeActive()) );
 }
