@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: freebsdAdvancedDialog.cpp,v 1.2 2004/10/24 03:45:54 vkurland Exp $
+  $Id: freebsdAdvancedDialog.cpp,v 1.4 2006/03/16 05:38:14 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,6 +28,7 @@
 #include "platforms.h"
 
 #include "freebsdAdvancedDialog.h"
+#include "ObjectManipulator.h"
 
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Management.h"
@@ -100,6 +101,7 @@ void freebsdAdvancedDialog::accept()
     assert(mgmt!=NULL);
 
     data.saveAll();
+    om->updateLastModifiedTimestampForAllFirewalls(obj);
 
     freebsdAdvancedDialog_q::accept();
 }
