@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instBatchOptionsDialog.cpp,v 1.5 2007/05/11 02:14:29 vkurland Exp $
+  $Id: instBatchOptionsDialog.cpp,v 1.6 2007/10/29 05:45:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -47,6 +47,10 @@ instBatchOptionsDialog::instBatchOptionsDialog(QWidget *parent, instConf *_cnf)
                              tr("Batch install options")+
                              QString("</font></b></p>")
     );
+    // must reset alt address in the dialog even though it is
+    // hidden. This is because we read it in instDialog::doInstallPage
+    // regardless of wether we perform batch install or not.
+    altAddress->setText("");
     altAddressLabel->hide();
     altAddress->hide();
     
