@@ -6,7 +6,7 @@
 
   Author:  Illiya Yalovoy <yalovoy@gmail.com>
 
-  $Id: instBatchOptionsDialog.h,v 1.2 2007/01/06 08:24:57 vkurland Exp $
+  $Id: instBatchOptionsDialog.h,v 1.3 2007/05/11 02:14:29 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -30,13 +30,15 @@
 #include "config.h"
 #include <instOptionsDialog.h>
 
+class instConf;
+
 class instBatchOptionsDialog : public instOptionsDialog
 {
     Q_OBJECT
  private:
  
  public:
-    instBatchOptionsDialog(QWidget *parent);
+    instBatchOptionsDialog(QWidget *parent, instConf *_cnf);
 
     
 };
