@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instConf.cpp,v 1.3 2004/11/06 22:45:36 vkurland Exp $
+  $Id: instConf.cpp,v 1.5 2007/05/11 03:39:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -26,11 +26,14 @@
 
 
 #include "../../config.h"
+#include "global.h"
+#include "utils.h"
 
 #include "instConf.h"
 
 #include "fwbuilder/Resources.h"
 #include "fwbuilder/FWException.h"
+#include "fwbuilder/Firewall.h"
 
 #include <iostream>
 
@@ -58,5 +61,29 @@ instConf::instConf()
     fwobj=NULL;
     maddr="";
     user="";
+    batchInstall=false;
+}
+
+QString instConf::getCmdFromResource(const QString &resource_name)
+{
+    if (fwbdebug)
+        qDebug(QString("instConf::getCmdFromResource testRun=%1  resource_name=%2").
+               arg(testRun).arg(resource_name));
+
+    string optpath_root = "activation/reg_user/";
+    string optpath;
+
+    if (testRun)
+        optpath_root = optpath_root + "test";
+    else
+        optpath_root = optpath_root + "run";
+    optpath = optpath_root + "/" + resource_name.ascii();
+    QString cmd = Resources::getTargetOptionStr(fwobj->getStr("host_OS"),
+                                                optpath).c_str();
+    cmd = cmd.stripWhiteSpace();
+    if (fwbdebug)
+        qDebug(QString("instConf::getCmdFromResource  cmd=%1").arg(cmd));
+
+    return cmd;
 }
 
