@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp,v 1.112 2007/11/02 15:14:41 vkurland Exp $
+  $Id: instDialog.cpp,v 1.113 2007/12/15 23:19:04 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -96,7 +96,21 @@ instDialog::instDialog(QWidget* p, BatchOperation op) : instDialog_q(p)
     showSelectedFlag=false;
     pendingLogLine = "";
 
-    proc.setCommunication( QProcess::Stdout|QProcess::Stderr|QProcess::DupStderr);
+    /* object proc is used to launch policy compilers as background
+     * processes. SSH sessions in installers are controlled by class
+     * SSHSession (and classes derived from it). This leads to some
+     * duplication, such as all the apparatus for reading from stdout
+     * of the background process is duplicated in SSHSession and here.
+     *
+     * The same object is also used to launch custom installer scripts.
+     *
+     * TODO(vadim): need to move everything that deals with compiler
+     * process into its own class CompilerSession derived from
+     * SSHSession. Perhaps also rename SSHSession to BackgroundSession
+     * or something.
+     */
+    proc.setCommunication(
+        QProcess::Stdout|QProcess::Stderr|QProcess::DupStderr);
 
     connect(&proc, SIGNAL(readyReadStdout()), this, SLOT(readFromStdout()) );
     connect(&proc, SIGNAL(processExited()),   this, SLOT(processExited()) );
@@ -113,7 +127,7 @@ instDialog::instDialog(QWidget* p, BatchOperation op) : instDialog_q(p)
     findFirewalls();
     if (firewalls.size()==0)
     {
-        setTitle( page(pageCount()-1), tr("There is no firewalls to process.") );
+        setTitle(page(pageCount()-1), tr("There are no firewalls to process."));
         for (int i=0;i<pageCount()-1;i++)
         {
             setAppropriate(page(i),false);
@@ -195,7 +209,7 @@ void instDialog::prepareInstallerOptions()
 {
     if (fwbdebug) qDebug("instDialog::prepareInstallerOptions");
     ready=false;
-    activationCommandDone=false;
+    activationCommandDone = false;
     FWOptions  *fwopt = cnf.fwobj->getOptionsObject();
 
     fwb_prompt="--**--**--";
@@ -879,10 +893,36 @@ bool instDialog::doInstallPage(Firewall* f)
     return true;
 }
 
+/* reset ssh session to continue the same installation process, such as
+ * when we need to copy several files to the firewall
+ */
 void instDialog::resetInstallSSHSession()
 {
     if (fwbdebug) qDebug("instDialog::resetInstallSSHSession");
 
+    if (session!=NULL)
+        QTimer::singleShot( 0, this, SLOT(stopSessionAndDisconnectSignals()));
+
+    activationCommandDone = false;
+
+    if (fwbdebug) qDebug("instDialog::resetInstallSSHSession  done");
+}
+
+/* instDialog::stopSessionAndDisconnectSignals runs when we have no
+ * other events in the events queue. This is necessary because call to
+ * instDialog::finishInstall can come from inside the state machine
+ * (e.g. when error was detected). This means we are trying to
+ * terminate working session right in the middle, when there could be
+ * some more output from its stdout to be collected. To avoid race
+ * conditions with events that have not been processed, we schedule
+ * all termination and clean-up operations so they will be done at
+ * idle time when there are no events in the queue
+ */
+void instDialog::stopSessionAndDisconnectSignals()
+{
+    if (fwbdebug)
+        qDebug("instDialog::stopSessionAndDisconnectSignals()");
+
     if (session!=NULL)
     {
         disconnect(session,SIGNAL(printStdout_sign(const QString&)),
@@ -903,7 +943,8 @@ void instDialog::resetInstallSSHSession()
         session=NULL;
     }
 
-    activationCommandDone=false;
+    if (fwbdebug)
+        qDebug("instDialog::stopSessionAndDisconnectSignals() done");
 }
 
 /*
@@ -1159,31 +1200,25 @@ void instDialog::finishInstall(bool success)
     
     if(opListIterator!=opList.end() && batchInstall->isChecked() && !stopProcessFlag) 
     {
-        installSelected();
+        QTimer::singleShot( 0, this, SLOT(installSelected()));
         return;
     }
     setNextEnabled( page(1), true);
 }
 
+/*
+ * continueRun is called via idle event handler after the session object
+ * is destroyed in stopSessionAndDisconnectSignals.
+ *
+ * Various methods call resetInstallSSHSession, which schedules call
+ * to stopSessionAndDisconnectSignals. installerFinished() also
+ * schedules call to continueRun() right after that. So continueRun()
+ * is always called when we have no active session object.
+ */
 void instDialog::continueRun()
 {
     if (fwbdebug) qDebug("instDialog::continueRun");
     
-    if (session)
-    {
-        if (session->getErrorStatus())
-        {
-            if (fwbdebug) qDebug("session error");
-            addToLog( tr("Fatal error, terminating install sequence\n") );
-            finishInstall(false);
-            //setFinishEnabled( page(1), true );
-            return;
-        }
-
-        delete session;
-        session=NULL;
-    }
-
     if (activationCommandDone)
     {
         if (fwbdebug) qDebug("activationCommandDone");
@@ -1255,7 +1290,7 @@ void instDialog::continueRun()
 
             if (cnf.verbose) displayCommand(args);
 
-            activationCommandDone=true;
+            activationCommandDone = true;
 
             runSSH( new SSHUnx(this,
                                cnf.fwobj->getName().c_str(),
@@ -1306,28 +1341,7 @@ void instDialog::updateProgressBar(int n,bool setsize)
 void instDialog::reject()
 {
     if (fwbdebug) qDebug("instDialog::reject()");
-    if (session!=NULL)
-    {
-        if (fwbdebug)
-            qDebug("instDialog::reject()  killing ssh session");
-
-        disconnect(session,SIGNAL(printStdout_sign(const QString&)),
-                   this,SLOT(append(const QString&)));
-
-        disconnect(session,SIGNAL(sessionFinished_sign()),
-                   this,SLOT(installerFinished()));
-
-        disconnect(session,SIGNAL(sessionFatalError_sign()),
-                   this,SLOT(installerError()));
-
-        disconnect(session,SIGNAL(updateProgressBar_sign(int,bool)),
-                   this,SLOT(updateProgressBar(int,bool)));
-
-        session->terminate();
-
-        delete session;
-        session=NULL;
-    }
+    stopSessionAndDisconnectSignals();
     QWizard::reject();
 }
 
@@ -1779,25 +1793,22 @@ void instDialog::installerError()
     addToLog( tr("Error: Terminating install sequence\n") );
     finishInstall(false);
 
-    resetInstallSSHSession();
-    //setFinishEnabled( page(1), true );
-
-    if (session) delete session;
-    session=NULL;
+    // session object is destroyed in stopSessionAndDisconnectSignals()
+    QTimer::singleShot( 0, this, SLOT(stopSessionAndDisconnectSignals()));
 }
 
 void instDialog::installerFinished()
 {
     if( fwbdebug) qDebug("instDialog::installerFinished");
-        
+
     if (session->getErrorStatus())
-    {
         installerError();
+    else
+    {
+        // session object is destroyed in stopSessionAndDisconnectSignals()
+        QTimer::singleShot( 0, this, SLOT(stopSessionAndDisconnectSignals()));
     }
-
-    if (session) delete session;
-    session=NULL;
-
+        
     QTimer::singleShot( 0, this, SLOT(continueRun()) );
 }
 
@@ -1829,7 +1840,7 @@ void instDialog::processExited()
         
         if (opListIterator!=opList.end() && batchInstall->isChecked() && !stopProcessFlag)
         {
-            installSelected();
+            QTimer::singleShot( 0, this, SLOT(installSelected()));
         }
         else
         {
@@ -1894,7 +1905,8 @@ void instDialog::processExited()
         }
         ++opListIterator;   
     }
-    if (currentFirewallsBar) currentFirewallsBar->setProgress(currentFirewallsBar->totalSteps());
+    if (currentFirewallsBar)
+        currentFirewallsBar->setProgress(currentFirewallsBar->totalSteps());
     
     if (currentStopButton)
     {
@@ -2102,12 +2114,12 @@ bool instDialog::runInstall(Firewall * fw)
         summary();
         proc.clearArguments();
 
-        proc.setArguments( args );
-        addToLog( proc.arguments().join(" ") );
+        proc.setArguments(args);
+        addToLog(proc.arguments().join(" "));
         addToLog("\n");
-        if ( !proc.start() )
+        if (!proc.start())
         {
-            addToLog( tr("Error: Failed to start program") );
+            addToLog(tr("Error: Failed to start program"));
             return false;
         }
         
