@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ipfAdvancedDialog.cpp,v 1.16 2007/01/06 22:03:25 vkurland Exp $
+  $Id: ipfAdvancedDialog.cpp,v 1.17 2007/10/07 01:21:07 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -88,6 +88,8 @@ ipfAdvancedDialog::ipfAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( ipf_nat_irc_proxy        ,fwopt, "ipf_nat_irc_proxy");
     data.registerOption( ipf_nat_ftp_proxy        ,fwopt, "ipf_nat_ftp_proxy");
     data.registerOption( ipf_nat_rcmd_proxy       ,fwopt, "ipf_nat_rcmd_proxy");
+    data.registerOption( ipf_nat_krcmd_proxy      ,fwopt, "ipf_nat_krcmd_proxy");
+    data.registerOption( ipf_nat_ekshell_proxy    ,fwopt, "ipf_nat_ekshell_proxy");
     data.registerOption( ipf_fw_dir               ,fwopt, "firewall_dir"      );
     data.registerOption( ipf_user                 ,fwopt, "admUser"           );
     data.registerOption( altAddress               ,fwopt, "altAddress"        );
