@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ipfwAdvancedDialog.cpp,v 1.12 2006/10/07 06:16:54 vkurland Exp $
+  $Id: ipfwAdvancedDialog.cpp,v 1.13 2007/01/06 22:03:25 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -139,7 +139,8 @@ void ipfwAdvancedDialog::reject()
 
 void ipfwAdvancedDialog::editProlog()
 {
-    SimpleTextEditor edt( prolog_script->text(),
+    SimpleTextEditor edt(this,
+                         prolog_script->text(),
                           true, tr( "Script Editor" ) );
     if ( edt.exec() == QDialog::Accepted )
         prolog_script->setText( edt.text() );
@@ -147,7 +148,8 @@ void ipfwAdvancedDialog::editProlog()
 
 void ipfwAdvancedDialog::editEpilog()
 {
-    SimpleTextEditor edt( epilog_script->text(),
+    SimpleTextEditor edt(this,
+                         epilog_script->text(),
                           true, tr( "Script Editor" ) );
     if ( edt.exec() == QDialog::Accepted )
         epilog_script->setText( edt.text() );
