@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: listOfLibraries.cpp,v 1.19 2006/11/09 16:13:21 vkurland Exp $
+  $Id: listOfLibraries.cpp,v 1.20 2007/02/04 04:20:26 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -193,6 +193,9 @@ list<libData>::iterator listOfLibraries::add(const QString &path, bool load)
     if (id.isEmpty()) return end();
     if (name.isEmpty()) return end();
 
+#if 0
+    // commented out for bug #1620284
+    //
 /*
  *  mw is NULL at this point if this method is called to preload
  *  libraries on startup
@@ -213,6 +216,7 @@ list<libData>::iterator listOfLibraries::add(const QString &path, bool load)
             0, 1 );
         return end();
     }
+#endif
 
     if (id == STANDARD_LIB) return end();
     if (id == DELETED_LIB)  return end();
