@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: newFirewallDialog.h,v 1.7 2005/04/27 05:35:54 vkurland Exp $
+  $Id: newFirewallDialog.h,v 1.8 2006/06/16 04:33:13 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -36,6 +36,7 @@
 
 namespace libfwbuilder {
     class FWObject;
+    class FWObjectDatabase;
     class Firewall;
     class Interface;
     class Logger;
@@ -56,6 +57,7 @@ class newFirewallDialog : public newFirewallDialog_q
     libfwbuilder::Logger               *logger;
     libfwbuilder::SNMP_interface_query *q;
     QTimer                             *timer;
+    libfwbuilder::FWObjectDatabase     *tmpldb;
     std::map<QListBoxItem*, libfwbuilder::FWObject*> templates;
     bool                                unloadTemplatesLib;
     bool                                getInterfacesBusy;
