@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: pfAdvancedDialog.cpp,v 1.21 2007/01/06 22:03:25 vkurland Exp $
+  $Id: pfAdvancedDialog.cpp,v 1.22 2007/07/14 18:17:45 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -72,16 +72,25 @@ pfAdvancedDialog::pfAdvancedDialog(QWidget *parent,FWObject *o)
         fwopt->setStr("firewall_dir","");
     }
 
-    data.registerOption( pf_log_prefix          ,fwopt, "log_prefix"          );
-    data.registerOption( pf_fallback_log        ,fwopt, "fallback_log"        );
-    data.registerOption( pf_do_timeout_interval ,fwopt, "pf_do_timeout_interval" );
-    data.registerOption( pf_timeout_interval    ,fwopt, "pf_timeout_interval" );
-    data.registerOption( pf_do_timeout_frag     ,fwopt, "pf_do_timeout_frag"     );
-    data.registerOption( pf_timeout_frag        ,fwopt, "pf_timeout_frag"     );
-    data.registerOption( pf_do_limit_frags      ,fwopt, "pf_do_limit_frags"      );
-    data.registerOption( pf_limit_frags         ,fwopt, "pf_limit_frags"      );
-    data.registerOption( pf_do_limit_states     ,fwopt, "pf_do_limit_states"     );
-    data.registerOption( pf_limit_states        ,fwopt, "pf_limit_states"     );
+    data.registerOption( pf_log_prefix       ,fwopt, "log_prefix"          );
+    data.registerOption( pf_fallback_log     ,fwopt, "fallback_log"        );
+    data.registerOption( pf_do_timeout_interval,fwopt,"pf_do_timeout_interval");
+    data.registerOption( pf_timeout_interval ,fwopt, "pf_timeout_interval" );
+    data.registerOption( pf_do_timeout_frag  ,fwopt, "pf_do_timeout_frag"     );
+    data.registerOption( pf_timeout_frag     ,fwopt, "pf_timeout_frag"     );
+    data.registerOption( pf_do_limit_frags   ,fwopt, "pf_do_limit_frags"      );
+    data.registerOption( pf_limit_frags      ,fwopt, "pf_limit_frags"      );
+    data.registerOption( pf_do_limit_states  ,fwopt, "pf_do_limit_states"     );
+    data.registerOption( pf_limit_states     ,fwopt, "pf_limit_states"     );
+    data.registerOption( pf_do_limit_src_nodes  ,fwopt,
+                         "pf_do_limit_src_nodes"  );
+    data.registerOption( pf_limit_src_nodes, fwopt, "pf_limit_src_nodes"  );
+    data.registerOption( pf_do_limit_tables, fwopt, "pf_do_limit_tables"     );
+    data.registerOption( pf_limit_tables     ,fwopt, "pf_limit_tables"     );
+    data.registerOption( pf_do_limit_table_entries,fwopt,
+                         "pf_do_limit_table_entries");
+    data.registerOption( pf_limit_table_entries,fwopt,"pf_limit_table_entries");
+
 // Prepare mapping for pf_optimization:
     slm.clear();
     slm.push_back("");
@@ -210,6 +219,10 @@ void pfAdvancedDialog::ltToggled()
 {
     pf_limit_frags->setEnabled( pf_do_limit_frags->isChecked() );
     pf_limit_states->setEnabled( pf_do_limit_states->isChecked() );
+    pf_limit_src_nodes->setEnabled( pf_do_limit_src_nodes->isChecked() );
+    pf_limit_tables->setEnabled( pf_do_limit_tables->isChecked() );
+    pf_limit_table_entries->setEnabled( pf_do_limit_table_entries->isChecked());
+
     pf_timeout_interval->setEnabled( pf_do_timeout_interval->isChecked() );
     pf_timeout_frag->setEnabled( pf_do_timeout_frag->isChecked() );
 
