@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: platforms.cpp,v 1.43 2007/07/14 22:02:01 vkurland Exp $
+  $Id: platforms.cpp,v 1.45 2007/12/15 20:32:16 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -49,6 +49,7 @@ QStringList logLevels;
 QStringList logFacilities;
 QStringList actionsOnReject;
 QStringList routeOptions_pf_ipf;
+QStringList routeLoadOptions_pf;
 QStringList prologPlaces_ipt;
 QStringList prologPlaces_pf;
 QStringList limitSuffixes;
@@ -135,6 +136,8 @@ void init_platforms()
     actionsOnReject.push_back(QObject::tr("TCP RST"));
     actionsOnReject.push_back("TCP RST");
 
+    routeOptions_pf_ipf.push_back(QObject::tr("None"));
+    routeOptions_pf_ipf.push_back("none");
     routeOptions_pf_ipf.push_back(QObject::tr("Route through"));
     routeOptions_pf_ipf.push_back("route_through");
     routeOptions_pf_ipf.push_back(QObject::tr("Route reply through"));
@@ -142,6 +145,15 @@ void init_platforms()
     routeOptions_pf_ipf.push_back(QObject::tr("Route a copy through"));
     routeOptions_pf_ipf.push_back("route_copy_through");
     
+    routeLoadOptions_pf.push_back(QObject::tr("None"));
+    routeLoadOptions_pf.push_back("none");
+    routeLoadOptions_pf.push_back(QObject::tr("Random"));
+    routeLoadOptions_pf.push_back("random");
+    routeLoadOptions_pf.push_back(QObject::tr("Source Hash"));
+    routeLoadOptions_pf.push_back("source_hash");
+    routeLoadOptions_pf.push_back(QObject::tr("Round Robin"));
+    routeLoadOptions_pf.push_back("round_robin");
+    
     prologPlaces_ipt.push_back(QObject::tr("on top of the script"));
     prologPlaces_ipt.push_back("top");
     prologPlaces_ipt.push_back(QObject::tr("after interface configuration"));
@@ -285,7 +297,7 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
         if (rule!=NULL)
         {
             PolicyRule::Action act=rule->getAction();
-            if (act==PolicyRule::Accept || act==PolicyRule::Tag)
+            if (act==PolicyRule::Accept || act==PolicyRule::Tag || act==PolicyRule::Route)
             {
                 // by default, these actions are not stateless
                 res = res && (!opt->getBool("stateless"));
@@ -399,6 +411,7 @@ list<QStringPair> getVersionsForPlatform(const QString &platform)
             {
                 res.push_back(QStringPair("","- any -"));
                 res.push_back(QStringPair("3.x", QObject::tr("3.x")));
+		res.push_back(QStringPair("ge_3.7", QObject::tr("3.7 to 3.9")));
                 res.push_back(QStringPair("4.x", QObject::tr("4.x")));
 /* add pf versions here */
             } else
@@ -459,6 +472,11 @@ const QStringList& getRouteOptions_pf_ipf(const QString &platform)
     return routeOptions_pf_ipf;
 }
 
+const QStringList& getRouteLoadOptions_pf(const QString &platform)
+{
+    return routeLoadOptions_pf;
+}
+
 const QStringList& getPrologPlaces(const QString &platform)
 {
     if (platform=="pf")
