@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: printerStream.cpp,v 1.4 2007/06/21 05:43:26 vkurland Exp $
+  $Id: printerStream.cpp,v 1.5 2008/05/09 04:29:28 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -40,18 +40,18 @@ printerStream::printerStream(QPrinter *p,
                              const QString &ht,
                              PrintingProgressDialog *pd) : pr(),metrics(p)
 {
-    printer=p;
-    margin=m;
-    printHeader=h;
-    headerText=ht;
-    ppd=pd;
-    headerFont=QFont( "times", 10, QFont::Normal );
-    bodyFont=QFont( "times", 14, QFont::Normal );
-    headerHeight=1.5;  // 1.5 cm for header
-    pageNo=0;
-    active=false;
-    fromPage=1;
-    toPage=9999;
+    printer = p;
+    margin = m;
+    printHeader = h;
+    headerText = ht;
+    ppd = pd;
+    headerFont = QFont( "times", 10, QFont::Normal );
+    bodyFont = QFont( "times", 14, QFont::Normal );
+    headerHeight = 1.5;  // 1.5 cm for header
+    pageNo = 0;
+    active = false;
+    fromPage = 1;
+    toPage = 9999;
 
     headerTimeString = QDateTime::currentDateTime().toString();
 }
@@ -66,14 +66,19 @@ bool printerStream::begin()
     pageHeight = metrics.height();
 
     if (fwbdebug)
+    {
         qDebug("printer dimensions: %dx%d",pageWidth,pageHeight);
+        qDebug("Margin: %.1f", margin);
+    }
 
     dpiy = metrics.logicalDpiY();
     ymargin = (int) ( (margin/2.54)*dpiy );
 // assuming printer's resolutions by X and Y axes are the same
     xmargin = ymargin;
-    pageBody=QRect( xmargin, ymargin,
-                    metrics.width() - 2*xmargin, metrics.height() - 2*ymargin );
+    pageBody = QRect( xmargin,
+                      ymargin,
+                      metrics.width() - 2*xmargin,
+                      metrics.height() - 2*ymargin );
 
     yHeaderHeight = int((headerHeight/2.54)*dpiy);
     yHeaderLine = int(((headerHeight-0.5)/2.54)*dpiy);
@@ -82,21 +87,30 @@ bool printerStream::begin()
     QFontMetrics fm = pr.fontMetrics();
     QRect br = fm.boundingRect("Page 999");
 
-    headerTextBox=QRect(xmargin,ymargin+yHeaderLine-fm.lineSpacing()-1,
-                        metrics.width()-2*xmargin,fm.lineSpacing()+1);
-    headerBox=QRect(xmargin,ymargin,metrics.width()-2*xmargin,yHeaderHeight);
+    headerTextBox = QRect(xmargin,
+                          ymargin + yHeaderLine - fm.lineSpacing() - 1,
+                          metrics.width() - 2 * xmargin,
+                          fm.lineSpacing() + 1);
+
+    headerBox = QRect(xmargin,
+                      ymargin,
+                      metrics.width() - 2 * xmargin,
+                      yHeaderHeight);
 
     if (fwbdebug)
     {
-        qDebug("dpiy=%d",dpiy);
-        qDebug("yHeaderHeight=%d",yHeaderHeight);
-        qDebug("yHeaderLine=%d",yHeaderLine);
-        qDebug("bounding rect for the header text: %d,%d,%d,%d",
-               br.left(),br.top(),br.width(),br.height());
-        qDebug("headerBox: %d,%d,%d,%d",
-               headerBox.left(),headerBox.top(),headerBox.width(),headerBox.height());
-        qDebug("headerTextBox: %d,%d,%d,%d",
-               headerTextBox.left(),headerTextBox.top(),headerTextBox.width(),headerTextBox.height());
+        qDebug("dpiy=%d", dpiy);
+        qDebug("yHeaderHeight=%d", yHeaderHeight);
+        qDebug("yHeaderLine=%d", yHeaderLine);
+        qDebug("fm.lineSpacing()=%d", fm.lineSpacing());
+        qDebug("bounding rect for the header text: l=%d,t=%d,w=%d,h=%d",
+               br.left(), br.top(), br.width(), br.height());
+        qDebug("headerBox: l=%d,t=%d,w=%d,h=%d",
+               headerBox.left(), headerBox.top(),
+               headerBox.width(), headerBox.height());
+        qDebug("headerTextBox: l=%d,t=%d,w=%d,h=%d",
+               headerTextBox.left(), headerTextBox.top(),
+               headerTextBox.width(), headerTextBox.height());
     }
 
     yPos = 0;
@@ -127,7 +141,8 @@ void printerStream::beginPage()
 
     if (printHeader)
     {
-        if (fwbdebug) qDebug("Printing header for page %d (%d-%d)",pageNo,fromPage,toPage);
+        if (fwbdebug) qDebug("Printing header for page %d (%d-%d)",
+                             pageNo, fromPage, toPage);
 
         QString page = QObject::tr("Page %1").arg(pageNo);
         if (pageNo>=fromPage && pageNo<=toPage)
@@ -168,6 +183,13 @@ int printerStream::getTextHeight(const QString &txt)
 
 void printerStream::printText(const QString &txt, bool newLine)
 {
+    if (fwbdebug)
+    {       
+        qDebug("printText ------- %s", txt.ascii());
+        qDebug("pageBody.height(): %d", pageBody.height());
+        qDebug("yPos: %d", yPos);
+    }
+
     if (txt.isEmpty()) return;
     if (printer->aborted()) return;
 
@@ -224,6 +246,9 @@ void printerStream::printQTable(QTable *tbl, bool left_margin, bool top_margin)
                tbl->viewport()->width(),tbl->viewport()->height());
         qDebug("Clipper: %dx%d",
                tbl->clipper()->width(),tbl->clipper()->height());
+        qDebug("YSpace: %d", getYSpace());
+        qDebug("pageBody.height(): %d", pageBody.height());
+        qDebug("yPos: %d", yPos);
     }
 
 
@@ -248,6 +273,7 @@ void printerStream::printQTable(QTable *tbl, bool left_margin, bool top_margin)
             if ( nth>getYSpace() ) { row--; break; }
             tblHeight  = nth;
         }
+
         // if row < firstRow then even single row does not fit on the page
         if (row < firstRow)
         {
@@ -255,18 +281,20 @@ void printerStream::printQTable(QTable *tbl, bool left_margin, bool top_margin)
             tblHeight = tbl->rowHeight(firstRow);
         }
 
-
         if (row == tbl->numRows()) row--;
 
         lastRow = row;
 
+        if (fwbdebug)
+            qDebug("Page %d -- (%d-%d of %d rows) tblHeight: %d",
+                   pageNo, firstRow, lastRow, tbl->numRows(), tblHeight);
+
         int firstRowPos = tbl->rowPos(firstRow);
         int lastRowPos = tbl->rowPos(lastRow);
            
         if (fwbdebug)
-            qDebug("Page %d -- %d rows (%d-%d) tblHeight: %d firstRowPos: %d lastRowPos: %d",
-                   pageNo, tbl->numRows(),
-                   firstRow, lastRow, tblHeight, firstRowPos, lastRowPos);
+            qDebug("    firstRowPos: %d lastRowPos: %d",
+                   firstRowPos, lastRowPos);
 
         int left_hdr_w = 0;
         if (left_margin && tbl->verticalHeader() != NULL)
@@ -276,8 +304,19 @@ void printerStream::printQTable(QTable *tbl, bool left_margin, bool top_margin)
         if (top_margin && tbl->horizontalHeader() != NULL)
             top_hdr_h = tbl->horizontalHeader()->height();
 
-        tbl->resize(tbl->contentsWidth()+ left_hdr_w, tblHeight);
-        tbl->clipper()->resize(getWorkspaceWidth(), tblHeight - top_hdr_h);
+        int tbl_w = tbl->contentsWidth() + left_hdr_w;
+        int tbl_h = tblHeight;
+        int clip_w = getWorkspaceWidth();
+        int clip_h = tblHeight - top_hdr_h;
+
+        if (fwbdebug) qDebug("    Resize table to %dx%d", tbl_w, tbl_h);
+        tbl->resize(tbl_w, tbl_h);
+        int n_tbl_w = tbl->width();
+        int n_tbl_h = tbl->height();
+        if (fwbdebug) qDebug("    New table size: %dx%d", n_tbl_w, n_tbl_h);
+
+        if (fwbdebug) qDebug("    Resize clipper to %dx%d", clip_w, clip_h);
+        tbl->clipper()->resize(clip_w, clip_h);
 
         tbl->verticalHeader()->resize(
             tbl->verticalHeader()->width(),
@@ -288,7 +327,7 @@ void printerStream::printQTable(QTable *tbl, bool left_margin, bool top_margin)
 
         if (fwbdebug)
         {       
-            qDebug("    After resize:");
+            qDebug("    ### After resize:");
             qDebug("    Size: %dx%d",tbl->width(),tbl->height());
             qDebug("    Contents: %dx%d",
                    tbl->contentsWidth(),tbl->contentsHeight());
@@ -309,7 +348,7 @@ void printerStream::printQTable(QTable *tbl, bool left_margin, bool top_margin)
 
         if (fwbdebug)
         {
-            qDebug("    After scroll:");
+            qDebug("    ### After scroll:");
             qDebug("    contents X: %d  contents Y: %d",
                    tbl->contentsX(),tbl->contentsY());
             int count = tbl->verticalHeader()->count();
