@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: utils.cpp,v 1.53 2007/04/03 15:48:45 vkurland Exp $
+  $Id: utils.cpp,v 1.55 2007/05/23 03:05:51 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -26,6 +26,7 @@
 #include "config.h"
 #include "global.h"
 #include "utils.h"
+#include "utils_no_qt.h"
 
 #include <qobject.h>
 #include <qpopupmenu.h>
@@ -63,6 +64,7 @@
 
 #include <iostream>
 #include <algorithm>
+#include <cctype>
 
 using namespace std;
 using namespace libfwbuilder;
@@ -350,42 +352,6 @@ void setHostOS(QComboBox *hostOS,const QString &os)
     }
 }
 
-/**
- * this method finds all firewalls in the tree and makes no
- * assumtions about tree structure
- */
-void findFirewalls(FWObject *o, std::list<FWObject*> &fwlist,
-                   bool skip_system_libs)
-{
-    findByObjectType(o,Firewall::TYPENAME,fwlist,skip_system_libs);
-}
-
-void findHosts(FWObject *o, std::list<FWObject*> &fwlist,
-               bool skip_system_libs)
-{
-    findByObjectType(o,Host::TYPENAME,fwlist,skip_system_libs);
-}
-
-void findByObjectType(FWObject *o,
-                      const string &otype,
-                      list<FWObject*> &fwlist,
-                      bool skip_system_libs)
-{
-    if (skip_system_libs)
-    {
-        if (o->getId()==DELETED_LIB) return;
-        if (o->getId()==TEMPLATE_LIB) return;
-    }
-    for (list<FWObject*>::iterator m=o->begin(); m!=o->end(); m++)
-    {
-        FWObject *o1=*m;
-        if (FWReference::cast(o1)!=NULL) continue;
-        if (o1->getTypeName()==otype) fwlist.push_back(o1);
-        else                   findByObjectType(o1,otype,fwlist);
-    }
-}
-
-
 void setDisabledPalette(QWidget *w)
 {
     QColorGroup cg;
@@ -498,20 +464,4 @@ QString wordWrap(const QString& s, int maxchinline)
     res.append(s.mid(linestart,pos-linestart));
     return res;
 }
-FWReference* findRef(FWObject *o,FWObject *p)
-{
-    
-    FWReference* ref=NULL;
-    FWObject::iterator i=p->begin();
-    for(;i!=p->end();++i)
-    {
-        ref=FWReference::cast(*i);
-        if (ref!=NULL && ref->getPointer() == o)
-        {
-            break;
-        }
-        ref=NULL;
-    }
-    return ref; 
-}
 
