@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipf.cpp,v 1.26 2006/09/15 05:48:22 vkurland Exp $
+  $Id: ipf.cpp,v 1.27 2006/09/21 06:29:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -94,6 +94,7 @@ static int              dl             = 0;
 static int              drp            = -1;
 static int              drn            = -1;
 static int              verbose        = 0;
+static bool             test_mode      = false;
 
 FWObjectDatabase       *objdb = NULL;
 
@@ -174,7 +175,9 @@ int main(int argc, char * const *argv)
             fw_file_name = string(optarg);
             break;
         case 'x':
-            if (*optarg=='p') {
+            if (*optarg=='t') {
+                test_mode = true;
+            } else if (*optarg=='p') {
                 ++optarg;
                 drp  = atoi(optarg);
             } else {
@@ -369,6 +372,7 @@ int main(int argc, char * const *argv)
 	c.setDebugLevel( dl );
 	c.setDebugRule(  drp );
 	c.setVerbose( verbose );
+        if (test_mode) c.setTestMode();
 
 	bool     have_ipf=false;
 	if ( c.prolog() > 0 ) {
@@ -383,6 +387,7 @@ int main(int argc, char * const *argv)
 	n.setDebugLevel( dl );
 	n.setDebugRule(  drn );
 	n.setVerbose( verbose );
+        if (test_mode) n.setTestMode();
 
 	bool     have_nat=false;
 	if ( n.prolog() > 0 ) {
