@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipfw.cpp,v 1.24 2006/09/15 05:48:22 vkurland Exp $
+  $Id: ipfw.cpp,v 1.25 2006/09/21 06:29:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -94,6 +94,7 @@ static int              dl             = 0;
 static int              drp            = -1;
 static int              drn            = -1;
 static int              verbose        = 0;
+static bool             test_mode      = false;
 
 FWObjectDatabase       *objdb = NULL;
 
@@ -154,7 +155,9 @@ int main(int argc, char * const *argv)
             fw_file_name = string(optarg);
             break;
         case 'x':
-            if (*optarg=='p') {
+            if (*optarg=='t') {
+                test_mode = true;
+            } else if (*optarg=='p') {
                 ++optarg;
                 drp  = atoi(optarg);
             } else {
@@ -330,6 +333,7 @@ int main(int argc, char * const *argv)
 	c.setDebugLevel( dl );
 	c.setDebugRule(  drp );
 	c.setVerbose( verbose );
+        if (test_mode) c.setTestMode();
 
 	bool     have_ipfw=false;
 	if ( c.prolog() > 0 ) 
