@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_PrintRule.cpp,v 1.13 2006/06/05 04:53:21 vkurland Exp $
+  $Id: NATCompiler_PrintRule.cpp,v 1.14 2006/10/08 00:10:02 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -391,7 +391,7 @@ string NATCompiler_ipt::PrintRule::_printDstService(RuleElementOSrv  *rel)
 	}
         if (TagService::isA(srv))
         {
-	    ostr << "--mark "
+	    ostr << "-m mark --mark "
                  << TagService::cast(srv)->getCode() << " ";
         }
 
