@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.cpp,v 1.26 2007/01/15 01:21:58 vkurland Exp $
+  $Id: NATCompiler_ipt.cpp,v 1.27 2007/10/29 06:33:14 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -2199,10 +2199,12 @@ void NATCompiler_ipt::compile()
 
         if (fwopt->getBool("use_iptables_restore"))
         {
-            if (have_dynamic_interfaces)
-                printRule=new PrintRuleIptRstEcho("generate code for iptables-restore using echo");
-            else
-                printRule=new PrintRuleIptRst("generate code for iptables-restore");
+            // bug #1812295: we should use PrintRuleIptRstEcho not only
+            // when we have dynamic interfaces, but also when we have
+            // address tables expanded at run time. Instead of checking
+            // for all these conditions, just always use PrintRuleIptRstEcho
+            printRule=new PrintRuleIptRstEcho(
+                "generate code for iptables-restore using echo");
         } else
             printRule=new PrintRule("generate iptables shell script");
 
