@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipt.h,v 1.5 2004/12/29 07:56:23 vkurland Exp $
+  $Id: NATCompiler_ipt.h,v 1.8 2006/06/05 04:53:21 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -60,6 +60,7 @@ namespace fwcompiler {
         bool   have_dynamic_interfaces;
 
         std::string getInterfaceVarName(libfwbuilder::FWObject *iface);
+        std::string getAddressTableVarName(libfwbuilder::FWObject *iface);
 
         /**
          * internal: scans child objects of interface iface, both IPv4
@@ -391,6 +392,34 @@ namespace fwcompiler {
                 eliminateDuplicatesInRE(n,libfwbuilder::RuleElementOSrv::TYPENAME) {}
         };
 
+        /**
+         * Split rule if MultiAddress object is used in RE to make
+         * sure it is single object.
+         */
+        class processMultiAddressObjectsInRE : public NATRuleProcessor
+        {
+            std::string re_type;
+            public:
+            processMultiAddressObjectsInRE(const std::string &name,
+                      const std::string &t) : NATRuleProcessor(name) { re_type=t; }
+            virtual bool processNext();
+        };
+
+
+        class processMultiAddressObjectsInOSrc : public processMultiAddressObjectsInRE
+        {
+            public:
+            processMultiAddressObjectsInOSrc(const std::string &n) :
+                processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementOSrc::TYPENAME) {}
+        };
+
+        class processMultiAddressObjectsInODst : public processMultiAddressObjectsInRE
+        {
+            public:
+            processMultiAddressObjectsInODst(const std::string &n) :
+                processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementODst::TYPENAME) {}
+        };
+
 
 	/**
 	 *   prints single policy rule, assuming all * groups have
@@ -433,6 +462,7 @@ namespace fwcompiler {
 
             public:
             PrintRule(const std::string &name);
+            virtual std::string _declareTable();
             virtual std::string _flushAndSetDefaultPolicy();
             virtual std::string _commit();
             virtual std::string _quote(const std::string &s);
@@ -450,6 +480,7 @@ namespace fwcompiler {
             public:
             
             PrintRuleIptRst(const std::string &name) : PrintRule(name) {};
+            virtual std::string _declareTable();
             virtual std::string _flushAndSetDefaultPolicy();
             virtual std::string _commit();
             virtual std::string _quote(const std::string &s);
@@ -466,6 +497,7 @@ namespace fwcompiler {
             public:
             
             PrintRuleIptRstEcho(const std::string &name) : PrintRuleIptRst(name) {};
+            virtual std::string _declareTable();
             virtual std::string _flushAndSetDefaultPolicy();
             virtual std::string _commit();
             virtual std::string _quote(const std::string &s);
