@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_linux24.h,v 1.2 2004/12/29 07:56:23 vkurland Exp $
+  $Id: OSConfigurator_linux24.h,v 1.7 2006/05/16 22:39:59 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -32,13 +32,19 @@
 
 #include "OSData.h"
 
+namespace libfwbuilder {
+    class FWObject;
+    class MultiAddressRunTime;
+};
+
 namespace fwcompiler {
 
     class OSConfigurator_linux24 : public OSConfigurator {
 
         OSData   os_data;
-
+        std::map<std::string,std::string>    address_table_objects;
 	std::vector<libfwbuilder::IPAddress> virtual_addresses;
+        std::list<std::string>               commands_to_add_virtual_addresses;
 
         std::string getInterfaceVarName(libfwbuilder::FWObject *iface);
         
@@ -59,8 +65,16 @@ namespace fwcompiler {
 	virtual void addVirtualAddressForNAT(const libfwbuilder::Address *addr);
 	virtual void addVirtualAddressForNAT(const libfwbuilder::Network *nw);
 
-        void         printPathForAllTools(const std::string &os);
-        void         configureInterfaces();
+        void registerMultiAddressObject(libfwbuilder::MultiAddressRunTime *at);
+        void printChecksForRunTimeMultiAddress();
+        void printShellFunctions();
+        std::string printPathForAllTools(const std::string &os);
+        void configureInterfaces();
+        void printCommandsToAddVirtualAddressesForNAT();
+        
+        std::string  printRunTimeWrappers(libfwbuilder::FWObject *rule,
+                                          const std::string &command);
+
     };
 };
 
