@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSData.h,v 1.1 2004/03/10 08:41:33 vkurland Exp $
+  $Id: OSData.h,v 1.3 2004/10/25 04:23:14 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -33,11 +33,14 @@
 
 
 class OSData {
-    public:
 
-    OSData();
+    std::string host_os;
     
-    typedef enum { LSMOD, MODPROBE , IPTABLES , IP , LOGGER } tools;
+ public:
+
+    OSData(const std::string &ho) { host_os=ho; }
+    
+    typedef enum { LSMOD, MODPROBE , IPTABLES , IPTABLES_RESTORE , IP , LOGGER } tools;
 
     std::string  getPathForTool(const std::string &distro,tools t);
 };
