@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt.h,v 1.28 2007/04/24 05:52:12 vkurland Exp $
+  $Id: PolicyCompiler_ipt.h,v 1.32 2007/07/08 01:11:35 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -61,6 +61,7 @@ namespace fwcompiler {
         PolicyCompiler_ipt::PrintRule *printRule;
         bool                           have_dynamic_interfaces;
         bool                           have_connmark;
+        bool                           have_connmark_in_output;
         std::string                    my_table;
         
         PolicyCompiler_ipt::PrintRule* createPrintRuleProcessor();
@@ -297,28 +298,36 @@ namespace fwcompiler {
 
 	/**
 	 * set chain if Tag rule should go into PREROUTING
-	 */
+	 *
         DECLARE_POLICY_RULE_PROCESSOR(setChainIfTagInPrerouting);
+        */
+        
+	/**
+	 * set chain if Tag rule should go into PREROUTING
+	 */
+        DECLARE_POLICY_RULE_PROCESSOR(setChainPreroutingForTag);
+
+	/**
+	 * set chain if Tag rule should go into POSTROUTING
+	 */
+        DECLARE_POLICY_RULE_PROCESSOR(setChainPostroutingForTag);
 
 	/**
 	 * set chain for mangle table
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(setChainForMangle);
 
+	/**
+	 * check if we need to do CONNMARK --restore-mark in OUTPUT chain
+	 */
+        DECLARE_POLICY_RULE_PROCESSOR(checkForRestoreMarkInOutput);
+
         
 	/**
 	 * split rule if action is Tag and connmark option is activated
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(splitIfTagAndConnmark);
 
-        /**
-         * packets that originate on the firewall should be marked in OUTPUT
-         * chain rather than in POSTROUTING because rerouting happens after
-         * OUTPUT hook but before POSTROUTING hook. See diagram at
-         * http://www.shorewall.net/NetfilterOverview.html 
-         */
-        DECLARE_POLICY_RULE_PROCESSOR(TagIfSrcFw);
-            
 	/**
 	 * split rule if Src==any 
 	 * 
@@ -756,6 +765,15 @@ namespace fwcompiler {
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(accounting);
 
+        
+        /**
+         * if action is Continue and logging is off, skip this rule.
+         * We only use action Continue to log some packets without making
+         * policy decision
+         */
+        DECLARE_POLICY_RULE_PROCESSOR(SkipActionContinueWithNoLogging);
+
+        
 	/**
 	 *  prints single policy rule, assuming all groups have been
 	 *  expanded, so source, destination and service hold exactly
@@ -804,7 +822,7 @@ namespace fwcompiler {
             virtual std::string _printTimeInterval(libfwbuilder::PolicyRule *r);
 
             virtual std::string _printLogParameters(libfwbuilder::PolicyRule *r);
-            virtual std::string _printLogPrefix(int rule_num,
+            virtual std::string _printLogPrefix(const std::string &rule_n,
 						const std::string &action,
 						const std::string &interf,
 						const std::string &chain,
@@ -890,6 +908,7 @@ namespace fwcompiler {
         {
             have_dynamic_interfaces = false;
             have_connmark = false;
+            have_connmark_in_output = false;
             printRule = NULL;
             my_table = "filter";
         }
