@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipt_optimizer.cpp,v 1.10 2006/12/28 06:00:23 vkurland Exp $
+  $Id: PolicyCompiler_ipt_optimizer.cpp,v 1.12 2007/07/19 01:46:30 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -130,7 +130,8 @@ void PolicyCompiler_ipt::optimize1::optimizeForRuleElement(PolicyRule    *rule,
     rule->setStr("ipt_chain",new_chain);
     rule->setBool("force_state_check",false);
     rule->setStr("upstream_rule_chain",this_chain);
-    rule->setInterfaceStr("nil");
+    if (rule->getInterfaceStr()=="")
+        rule->setInterfaceStr("nil");
     rule->setDirection( PolicyRule::Both ); 
    
     tmp_queue.push_back(rule);
@@ -255,9 +256,10 @@ bool PolicyCompiler_ipt::optimize2::processNext()
 }
 
 /*
- *  this processor eliminates duplicate rules _generated for the same high level rule_
- *  This is different from processor PolicyCompiler_ipf::eliminateDuplicateRules, which
- *  finds and eliminates duplicate rules throughout the whole generated script.
+ *  this processor eliminates duplicate rules _generated for the same
+ *  high level rule_ This is different from processor
+ *  PolicyCompiler_ipf::eliminateDuplicateRules, which finds and
+ *  eliminates duplicate rules throughout the whole generated script.
  */
 bool PolicyCompiler_ipt::optimize3::processNext()
 {
