@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland <vadim@vk.crocodile.org>
 
-  $Id: combinedAddress.h,v 1.1 2004/03/10 08:41:33 vkurland Exp $
+  $Id: combinedAddress.h,v 1.2 2006/09/11 00:41:09 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -45,7 +45,7 @@ class combinedAddress : public IPv4
     DECLARE_FWOBJECT_SUBTYPE(combinedAddress);
 
     combinedAddress() {}
-    combinedAddress(const FWObject *root);
+    combinedAddress(const FWObject *root,bool prepopulate);
     virtual ~combinedAddress();
 
     std::string getPhysAddress() const;
