@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: ipt.cpp,v 1.60 2006/09/21 06:29:43 vkurland Exp $
+  $Id: ipt.cpp,v 1.64 2007/12/15 23:19:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -91,6 +91,7 @@ static int              dl             = 0;
 static int              drp            = -1;
 static int              drn            = -1;
 static int              verbose        = 0;
+static bool             omit_timestamp = false;
 static bool             have_dynamic_interfaces = false;
 static bool             test_mode      = false;
 
@@ -134,7 +135,7 @@ void usage(const char *name)
 {
     cout << _("Firewall Builder:  policy compiler for Linux 2.4.x and 2.6.x iptables") << endl;
     cout << _("Version ") << VERSION << "-" << RELEASE_NUM << endl;
-    cout << _("Usage: ") << name << _(" [-x level] [-v] [-V] [-f filename.xml] [-d destdir] [-m] firewall_object_name") << endl;
+    cout << _("Usage: ") << name << _(" [-x level] [-v] [-V] [-q] [-f filename.xml] [-d destdir] [-m] firewall_object_name") << endl;
 }
 
 int main(int argc, char * const *argv)
@@ -160,7 +161,7 @@ int main(int argc, char * const *argv)
 
     int   opt;
 
-    while( (opt=getopt(argc,argv,"x:vVf:d:r:o:")) != EOF )
+    while( (opt=getopt(argc,argv,"x:vVqf:d:r:o:")) != EOF )
     {
         switch(opt)
         {
@@ -201,6 +202,9 @@ int main(int argc, char * const *argv)
         case 'V':
             usage(argv[0]);
             exit(1);
+        case 'q':
+            omit_timestamp = true;
+            break;
         }
     }
     
@@ -499,10 +503,14 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
         script << _("#\n\
 #  This is automatically generated file. DO NOT MODIFY !\n\
 #\n\
-#  Firewall Builder  fwb_ipt v") << VERSION << "-" << RELEASE_NUM << _(" \n\
-#\n\
+#  Firewall Builder  fwb_ipt v") << VERSION << "-" << RELEASE_NUM << _(" \n");
+
+        if (!omit_timestamp)
+        {
+            script << _("#\n\
 #  Generated ") << timestr << " " << tzname[stm->tm_isdst] << _(" by ") 
                << user_name << "\n#\n";
+        }
 
         script << MANIFEST_MARKER << "* " << fw_file_name << endl;
         script << "#" << endl;
@@ -561,8 +569,13 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
         }
 
         script << "log '";
-        script << _("Activating firewall script generated ")
-               << timestr << " " << _(" by ")
+        if (omit_timestamp)
+        {
+            script << _("Activating firewall script");
+        } else
+        {
+            script << _("Activating firewall script generated ")
+                   << timestr << " " << _(" by ")
 /* timezone removed because of bug #1205665 - sometimes timezone name
  * has "'" in it which confuses shell and causes an error (for
  * instance French daylight savings time is "Paris, Madrid (heure
@@ -570,72 +583,42 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
  * 
  *               << timestr << " " << tzname[stm->tm_isdst] << _(" by ")
  */
-               << user_name;
+                   << user_name;
+        }
+
         script << "'" << endl;
 
 	script << endl;
 
         if (options->getBool("use_iptables_restore"))
         {
-            if (have_dynamic_interfaces)
+            script << "(" << endl;
+
+            script << c.flushAndSetDefaultPolicy();
+
+            if (prolog_place == "after_flush")
             {
-                script << "(" << endl;
-
-                script << c.flushAndSetDefaultPolicy();
-
-                if (prolog_place == "after_flush")
-                {
-                    script << addPrologScript(nocomm, 
-                                 fw->getOptionsObject()->getStr("prolog_script"));
-                }
-
-                script << c.getCompiledScript();
-                script << c.commit();
-
-                if (m.getCompiledScriptLength()>0)
-                {
-                    script << m.flushAndSetDefaultPolicy();
-                    script << m.getCompiledScript();
-                    script << m.commit();
-                }
-                if (n.getCompiledScriptLength()>0)
-                {
-                    script << n.flushAndSetDefaultPolicy();
-                    script << n.getCompiledScript();
-                    script << n.commit();
-                }
-                script << "#" << endl;
-                script << ") | $IPTABLES_RESTORE" << endl;
-            } else
-            {
-                script << "cat << EOF | $IPTABLES_RESTORE" << endl;
-
-                script << c.flushAndSetDefaultPolicy();
-
-                if (prolog_place == "after_flush")
-                {
-                    script << addPrologScript(nocomm, 
-                                 fw->getOptionsObject()->getStr("prolog_script"));
-                }
-
-                script << c.getCompiledScript();
-                script << c.commit();
-
-                if (m.getCompiledScriptLength()>0)
-                {
-                    script << m.flushAndSetDefaultPolicy();
-                    script << m.getCompiledScript();
-                    script << m.commit();
-                }
-                if (n.getCompiledScriptLength()>0)
-                {
-                    script << n.flushAndSetDefaultPolicy();
-                    script << n.getCompiledScript();
-                    script << n.commit();
-                }
-                script << "#" << endl;
-                script << "EOF" << endl;
+                script << addPrologScript(nocomm, 
+                                          fw->getOptionsObject()->getStr("prolog_script"));
             }
+
+            script << c.getCompiledScript();
+            script << c.commit();
+
+            if (m.getCompiledScriptLength()>0)
+            {
+                script << m.flushAndSetDefaultPolicy();
+                script << m.getCompiledScript();
+                script << m.commit();
+            }
+            if (n.getCompiledScriptLength()>0)
+            {
+                script << n.flushAndSetDefaultPolicy();
+                script << n.getCompiledScript();
+                script << n.commit();
+            }
+            script << "#" << endl;
+            script << ") | $IPTABLES_RESTORE; IPTABLES_RESTORE_RES=$?" << endl;
         } else
         {
 
@@ -692,52 +675,15 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
             script << "#" << endl;
         }
 
+        script << endl;
+
+        if (options->getBool("use_iptables_restore"))
+            script << "exit $IPTABLES_RESTORE_RES";
+
 	script << endl;
 
         string sbuf = script.str();
 
-/* starting with 2.0.3 we copy script to linksys using scp and do not
- * need to escape double quotes and '$' anymore
- */
-
-#if 0
-        if ( Resources::getTargetOptionBool(fw->getStr("host_OS"),
-                                            "escape_everything") )
-        {
-/* need to escape single and double quotes, as well as '$' in the script */
-
-            string::size_type i;
-
-            i = 0;
-            while ( (i=sbuf.find('\"',i))!=string::npos )
-            {
-                sbuf.replace(i,1,"\\\"");
-                i+=2;
-            }
-
-            i = 0;
-            while ( (i=sbuf.find('\'',i))!=string::npos )
-            {
-                sbuf.replace(i,1,"\\\'");
-                i+=2;
-            }
-
-            i = 0;
-            while ( (i=sbuf.find('`',i))!=string::npos )
-            {
-                sbuf.replace(i,1,"\\`");
-                i+=2;
-            }
-
-            i = 0;
-            while ( (i=sbuf.find('$',i))!=string::npos )
-            {
-                sbuf.replace(i,1,"\\$");
-                i+=2;
-            }
-        }
-#endif
-
 	ofstream fw_file;
         fw_file.exceptions(ofstream::eofbit|ofstream::failbit|ofstream::badbit);
 
