@@ -160,7 +160,7 @@ void IOSCfgParser::version() {
 		if ( inputState->guessing==0 ) {
 #line 126 "iosacl.g"
 			
-			dbg << "VERSION " << v->getText() << std::endl;
+			*dbg << "VERSION " << v->getText() << std::endl;
 			
 #line 166 "IOSCfgParser.cpp"
 		}
@@ -202,7 +202,7 @@ void IOSCfgParser::hostname() {
 #line 133 "iosacl.g"
 			
 			importer->setHostName( LT(0)->getText() );
-			dbg << "HOSTNAME "
+			*dbg << "HOSTNAME "
 			<< "LT0=" << LT(0)->getText()
 			<< std::endl;
 			
@@ -271,7 +271,7 @@ void IOSCfgParser::intrface() {
 #line 443 "iosacl.g"
 			
 			importer->newInterface( in->getText() );
-			dbg << in->getLine() << ":"
+			*dbg << in->getLine() << ":"
 			<< " INTRFACE: " << in->getText() << std::endl;
 			
 #line 278 "IOSCfgParser.cpp"
@@ -342,7 +342,7 @@ void IOSCfgParser::access_list_commands() {
 #line 148 "iosacl.g"
 			
 			importer->newUnidirRuleSet( std::string("acl_") + acl_num->getText() );
-			dbg << acl_num->getLine() << ":"
+			*dbg << acl_num->getLine() << ":"
 			<< " ACL #" << acl_num->getText() << " ";
 			
 #line 349 "IOSCfgParser.cpp"
@@ -403,7 +403,7 @@ void IOSCfgParser::description() {
 		if ( inputState->guessing==0 ) {
 #line 454 "iosacl.g"
 			
-			dbg << LT(1)->getLine() << ":";
+			*dbg << LT(1)->getLine() << ":";
 			std::string descr;
 			while (LA(1) != ANTLR_USE_NAMESPACE(antlr)Token::EOF_TYPE && LA(1) != NEWLINE)
 			{
@@ -411,7 +411,7 @@ void IOSCfgParser::description() {
 			consume();
 			}
 			importer->addInterfaceComment( descr );
-			dbg << " INTERFACE DESCRIPTION " << descr << std::endl;
+			*dbg << " INTERFACE DESCRIPTION " << descr << std::endl;
 			//consumeUntil(NEWLINE);
 			
 #line 418 "IOSCfgParser.cpp"
@@ -435,7 +435,7 @@ void IOSCfgParser::shutdown() {
 		if ( inputState->guessing==0 ) {
 #line 487 "iosacl.g"
 			
-			dbg<< LT(1)->getLine() << ":"
+			*dbg<< LT(1)->getLine() << ":"
 			<< " INTERFACE SHUTDOWN " << std::endl;
 			
 #line 442 "IOSCfgParser.cpp"
@@ -487,7 +487,7 @@ void IOSCfgParser::ip_access_list_ext() {
 #line 169 "iosacl.g"
 			
 			importer->newUnidirRuleSet( name->getText() );
-			dbg << name->getLine() << ":"
+			*dbg << name->getLine() << ":"
 			<< " ACL ext " << name->getText() << std::endl;
 			
 #line 494 "IOSCfgParser.cpp"
@@ -530,7 +530,7 @@ void IOSCfgParser::ip_access_list_ext() {
 		if ( inputState->guessing==0 ) {
 #line 186 "iosacl.g"
 			
-			dbg << LT(0)->getLine() << ":"
+			*dbg << LT(0)->getLine() << ":"
 			<< " ACL end" << std::endl << std::endl;
 			
 #line 537 "IOSCfgParser.cpp"
@@ -587,7 +587,7 @@ void IOSCfgParser::permit_std() {
 			
 			importer->newPolicyRule();
 			importer->action = "permit";
-			dbg << LT(1)->getLine() << ":" << " permit ";
+			*dbg << LT(1)->getLine() << ":" << " permit ";
 			
 #line 593 "IOSCfgParser.cpp"
 		}
@@ -621,7 +621,7 @@ void IOSCfgParser::deny_std() {
 			
 			importer->newPolicyRule();
 			importer->action = "deny";
-			dbg << LT(1)->getLine() << ":" << " deny   ";
+			*dbg << LT(1)->getLine() << ":" << " deny   ";
 			
 #line 627 "IOSCfgParser.cpp"
 		}
@@ -655,7 +655,7 @@ void IOSCfgParser::permit_ext() {
 			
 			importer->newPolicyRule();
 			importer->action = "permit";
-			dbg << LT(1)->getLine() << ":" << " permit ";
+			*dbg << LT(1)->getLine() << ":" << " permit ";
 			
 #line 661 "IOSCfgParser.cpp"
 		}
@@ -689,7 +689,7 @@ void IOSCfgParser::deny_ext() {
 			
 			importer->newPolicyRule();
 			importer->action = "deny";
-			dbg << LT(1)->getLine() << ":" << " deny   ";
+			*dbg << LT(1)->getLine() << ":" << " deny   ";
 			
 #line 695 "IOSCfgParser.cpp"
 		}
@@ -721,7 +721,7 @@ void IOSCfgParser::remark() {
 		if ( inputState->guessing==0 ) {
 #line 472 "iosacl.g"
 			
-			dbg << LT(1)->getLine() << ":";
+			*dbg << LT(1)->getLine() << ":";
 			std::string rem;
 			while (LA(1) != ANTLR_USE_NAMESPACE(antlr)Token::EOF_TYPE && LA(1) != NEWLINE)
 			{
@@ -729,7 +729,7 @@ void IOSCfgParser::remark() {
 			consume();
 			}
 			importer->addRuleComment( rem );
-			dbg << " REMARK " << rem << std::endl;
+			*dbg << " REMARK " << rem << std::endl;
 			//consumeUntil(NEWLINE);
 			
 #line 736 "IOSCfgParser.cpp"
@@ -758,13 +758,13 @@ void IOSCfgParser::rule_ext() {
 			hostaddr_ext();
 			if ( inputState->guessing==0 ) {
 #line 247 "iosacl.g"
-				importer->SaveTmpAddrToSrc(); dbg << "(src) ";
+				importer->SaveTmpAddrToSrc(); *dbg << "(src) ";
 #line 763 "IOSCfgParser.cpp"
 			}
 			hostaddr_ext();
 			if ( inputState->guessing==0 ) {
 #line 248 "iosacl.g"
-				importer->SaveTmpAddrToDst(); dbg << "(dst) ";
+				importer->SaveTmpAddrToDst(); *dbg << "(dst) ";
 #line 769 "IOSCfgParser.cpp"
 			}
 			{
@@ -833,20 +833,20 @@ void IOSCfgParser::rule_ext() {
 #line 254 "iosacl.g"
 				
 				importer->protocol = LT(0)->getText();
-				dbg << "protocol " << LT(0)->getText() << " ";
+				*dbg << "protocol " << LT(0)->getText() << " ";
 				
 #line 839 "IOSCfgParser.cpp"
 			}
 			hostaddr_ext();
 			if ( inputState->guessing==0 ) {
 #line 258 "iosacl.g"
-				importer->SaveTmpAddrToSrc(); dbg << "(src) ";
+				importer->SaveTmpAddrToSrc(); *dbg << "(src) ";
 #line 845 "IOSCfgParser.cpp"
 			}
 			hostaddr_ext();
 			if ( inputState->guessing==0 ) {
 #line 259 "iosacl.g"
-				importer->SaveTmpAddrToDst(); dbg << "(dst) ";
+				importer->SaveTmpAddrToDst(); *dbg << "(dst) ";
 #line 851 "IOSCfgParser.cpp"
 			}
 			{
@@ -955,14 +955,14 @@ void IOSCfgParser::rule_ext() {
 #line 266 "iosacl.g"
 				
 				importer->protocol = LT(0)->getText();
-				dbg << "protocol " << LT(0)->getText() << " ";
+				*dbg << "protocol " << LT(0)->getText() << " ";
 				
 #line 961 "IOSCfgParser.cpp"
 			}
 			hostaddr_ext();
 			if ( inputState->guessing==0 ) {
 #line 270 "iosacl.g"
-				importer->SaveTmpAddrToSrc(); dbg << "(src) ";
+				importer->SaveTmpAddrToSrc(); *dbg << "(src) ";
 #line 967 "IOSCfgParser.cpp"
 			}
 			{
@@ -996,7 +996,7 @@ void IOSCfgParser::rule_ext() {
 			hostaddr_ext();
 			if ( inputState->guessing==0 ) {
 #line 272 "iosacl.g"
-				importer->SaveTmpAddrToDst(); dbg << "(dst) ";
+				importer->SaveTmpAddrToDst(); *dbg << "(dst) ";
 #line 1001 "IOSCfgParser.cpp"
 			}
 			{
@@ -1119,7 +1119,7 @@ void IOSCfgParser::rule_ext() {
 		if ( inputState->guessing==0 ) {
 #line 279 "iosacl.g"
 			
-			dbg << std::endl;
+			*dbg << std::endl;
 			
 #line 1125 "IOSCfgParser.cpp"
 		}
@@ -1142,7 +1142,7 @@ void IOSCfgParser::rule_std() {
 		hostaddr_std();
 		if ( inputState->guessing==0 ) {
 #line 287 "iosacl.g"
-			importer->SaveTmpAddrToSrc(); dbg << "(std) ";
+			importer->SaveTmpAddrToSrc(); *dbg << "(std) ";
 #line 1147 "IOSCfgParser.cpp"
 		}
 		{
@@ -1167,7 +1167,7 @@ void IOSCfgParser::rule_std() {
 		if ( inputState->guessing==0 ) {
 #line 290 "iosacl.g"
 			
-			dbg << std::endl;
+			*dbg << std::endl;
 			
 #line 1173 "IOSCfgParser.cpp"
 		}
@@ -1208,7 +1208,7 @@ void IOSCfgParser::ip_protocols() {
 #line 298 "iosacl.g"
 			
 			importer->protocol = LT(0)->getText();
-			dbg << "protocol " << LT(0)->getText() << " ";
+			*dbg << "protocol " << LT(0)->getText() << " ";
 			
 #line 1214 "IOSCfgParser.cpp"
 		}
@@ -1243,7 +1243,7 @@ void IOSCfgParser::hostaddr_ext() {
 				
 				importer->tmp_a = h->getText();
 				importer->tmp_nm = "0.0.0.0";
-				dbg << h->getText() << "/0.0.0.0";
+				*dbg << h->getText() << "/0.0.0.0";
 				
 #line 1249 "IOSCfgParser.cpp"
 			}
@@ -1262,7 +1262,7 @@ void IOSCfgParser::hostaddr_ext() {
 				
 				importer->tmp_a = a->getText();
 				importer->tmp_nm = m->getText();
-				dbg << a->getText() << "/" << m->getText();
+				*dbg << a->getText() << "/" << m->getText();
 				
 #line 1268 "IOSCfgParser.cpp"
 			}
@@ -1276,7 +1276,7 @@ void IOSCfgParser::hostaddr_ext() {
 				
 				importer->tmp_a = "0.0.0.0";
 				importer->tmp_nm = "0.0.0.0";
-				dbg << "0.0.0.0/0.0.0.0";
+				*dbg << "0.0.0.0/0.0.0.0";
 				
 #line 1282 "IOSCfgParser.cpp"
 			}
@@ -1310,7 +1310,7 @@ void IOSCfgParser::time_range() {
 #line 416 "iosacl.g"
 			
 			importer->time_range_name = tr_name->getText();
-			dbg << "time_range " << tr_name->getText() << " ";
+			*dbg << "time_range " << tr_name->getText() << " ";
 			
 #line 1316 "IOSCfgParser.cpp"
 		}
@@ -1334,7 +1334,7 @@ void IOSCfgParser::fragments() {
 #line 409 "iosacl.g"
 			
 			importer->fragments = true;
-			dbg << "fragments ";
+			*dbg << "fragments ";
 			
 #line 1340 "IOSCfgParser.cpp"
 		}
@@ -1375,7 +1375,7 @@ void IOSCfgParser::log() {
 #line 395 "iosacl.g"
 			
 			importer->logging = true;
-			dbg << "logging ";
+			*dbg << "logging ";
 			
 #line 1381 "IOSCfgParser.cpp"
 		}
@@ -1413,7 +1413,7 @@ void IOSCfgParser::icmp_spec() {
 				importer->icmp_type = icmp_type->getText();
 				importer->icmp_code = icmp_code->getText();
 				importer->icmp_spec = "";
-				dbg << icmp_type->getText() << " "
+				*dbg << icmp_type->getText() << " "
 				<< icmp_code->getText() << " ";
 				
 #line 1420 "IOSCfgParser.cpp"
@@ -1428,7 +1428,7 @@ void IOSCfgParser::icmp_spec() {
 #line 315 "iosacl.g"
 				
 				importer->icmp_spec = icmp_word->getText();
-				dbg << icmp_word->getText() << " ";
+				*dbg << icmp_word->getText() << " ";
 				
 #line 1434 "IOSCfgParser.cpp"
 			}
@@ -1494,7 +1494,7 @@ void IOSCfgParser::established() {
 #line 402 "iosacl.g"
 			
 			importer->established = true;
-			dbg << "established ";
+			*dbg << "established ";
 			
 #line 1500 "IOSCfgParser.cpp"
 		}
@@ -1526,7 +1526,7 @@ void IOSCfgParser::hostaddr_std() {
 				
 				importer->tmp_a = h->getText();
 				importer->tmp_nm = "0.0.0.0";
-				dbg << h->getText() << "/0.0.0.0";
+				*dbg << h->getText() << "/0.0.0.0";
 				
 #line 1532 "IOSCfgParser.cpp"
 			}
@@ -1543,7 +1543,7 @@ void IOSCfgParser::hostaddr_std() {
 				
 				importer->tmp_a = a->getText();
 				importer->tmp_nm = m->getText();
-				dbg << a->getText() << "/" << m->getText();
+				*dbg << a->getText() << "/" << m->getText();
 				
 #line 1549 "IOSCfgParser.cpp"
 			}
@@ -1555,7 +1555,7 @@ void IOSCfgParser::hostaddr_std() {
 				
 				importer->tmp_a = "0.0.0.0";
 				importer->tmp_nm = "0.0.0.0";
-				dbg << "0.0.0.0/0.0.0.0";
+				*dbg << "0.0.0.0/0.0.0.0";
 				
 #line 1561 "IOSCfgParser.cpp"
 			}
@@ -1611,7 +1611,7 @@ void IOSCfgParser::single_port_op() {
 #line 326 "iosacl.g"
 			
 			importer->tmp_port_op = LT(0)->getText();
-			dbg << LT(0)->getText() << " ";
+			*dbg << LT(0)->getText() << " ";
 			
 #line 1617 "IOSCfgParser.cpp"
 		}
@@ -1636,7 +1636,7 @@ void IOSCfgParser::port_range() {
 #line 334 "iosacl.g"
 			
 			importer->tmp_port_op = LT(0)->getText();
-			dbg << LT(0)->getText() << " ";
+			*dbg << LT(0)->getText() << " ";
 			
 #line 1642 "IOSCfgParser.cpp"
 		}
@@ -1679,7 +1679,7 @@ void IOSCfgParser::port_spec() {
 #line 342 "iosacl.g"
 			
 			importer->tmp_port_spec += (std::string(" ") + LT(0)->getText());
-			dbg << LT(0)->getText() << " ";
+			*dbg << LT(0)->getText() << " ";
 			
 #line 1685 "IOSCfgParser.cpp"
 		}
@@ -1712,7 +1712,7 @@ void IOSCfgParser::access_group_by_name() {
 			acln->getText(),
 			"",
 			dir->getText() );
-			dbg << LT(1)->getLine() << ":"
+			*dbg << LT(1)->getLine() << ":"
 			<< " INTRFACE: ACL '" << acln->getText() << "'"
 			<< " " << dir->getText() << std::endl;
 			
@@ -1747,7 +1747,7 @@ void IOSCfgParser::access_group_by_number() {
 			std::string("acl_") + acln->getText(),
 			"",
 			dir->getText() );
-			dbg << LT(1)->getLine() << ":"
+			*dbg << LT(1)->getLine() << ":"
 			<< " INTRFACE: ACL '" << acln->getText() << "'"
 			<< " " << dir->getText() << std::endl;
 			
@@ -1798,14 +1798,14 @@ void IOSCfgParser::intf_address() {
 #line 540 "iosacl.g"
 			
 			importer->addInterfaceAddress(a->getText(), m->getText());
-			dbg << LT(1)->getLine() << ":"
+			*dbg << LT(1)->getLine() << ":"
 			<< " INTRFACE ADDRESS: " << a->getText()
 			<< "/" << m->getText() << " ";
 			if (s)
 			{
-			dbg << s->getText();
+			*dbg << s->getText();
 			}
-			dbg <<  std::endl;
+			*dbg <<  std::endl;
 			
 #line 1811 "IOSCfgParser.cpp"
 		}
