@@ -52,8 +52,8 @@ struct CUSTOM_API IPTCfgParserTokenTypes {
 		ULOG_PREFIX = 41,
 		LOG_LEVEL = 42,
 		SET_MARK = 43,
-		SET_TOS = 44,
-		HEX_CONST = 45,
+		HEX_CONST = 44,
+		SET_TOS = 45,
 		SAVE_MARK = 46,
 		RESTORE_MARK = 47,
 		CONTINUE = 48,
@@ -65,68 +65,70 @@ struct CUSTOM_API IPTCfgParserTokenTypes {
 		TO_DESTINATION = 54,
 		TO_PORTS = 55,
 		TO_NETMAP = 56,
-		OPT_FRAGM = 57,
-		INVALID = 58,
-		NEW = 59,
-		ESTABLISHED = 60,
-		RELATED = 61,
-		M_STATE = 62,
-		MATCH_STATE = 63,
-		COMMA = 64,
-		M_MARK = 65,
-		MATCH_MARK = 66,
-		M_LIMIT = 67,
-		MATCH_LIMIT = 68,
-		MATCH_LIMIT_BURST = 69,
-		M_MPORT = 70,
-		MATCH_SRC_MULTIPORT = 71,
-		MATCH_SRC_MULTIPORT_SHORT = 72,
-		MATCH_DST_MULTIPORT = 73,
-		MATCH_DST_MULTIPORT_SHORT = 74,
-		MATCH_ICMP_TYPE = 75,
-		MATCH_SRC_PORT = 76,
-		MATCH_SRC_PORT_SHORT = 77,
-		MATCH_DST_PORT = 78,
-		MATCH_DST_PORT_SHORT = 79,
-		MATCH_SYN = 80,
-		SYN = 81,
-		ACK = 82,
-		FIN = 83,
-		RST = 84,
-		URG = 85,
-		PSH = 86,
-		ALL = 87,
-		NONE = 88,
-		MATCH_TCP_FLAGS = 89,
-		Whitespace = 90,
-		NEG_INT_CONST = 91,
-		HEXDIGIT = 92,
-		NUMBER = 93,
-		SECONDS = 94,
-		SET = 95,
-		RSOURCE = 96,
-		ULOG_QTHR = 97,
-		ULOG_NLG = 98,
-		ULOG_CPR = 99,
-		NUMBER_SIGN = 100,
-		PERCENT = 101,
-		AMPERSAND = 102,
-		APOSTROPHE = 103,
-		OPENING_PAREN = 104,
-		CLOSING_PAREN = 105,
-		PLUS = 106,
-		DOT = 107,
-		SEMICOLON = 108,
-		LESS_THAN = 109,
-		EQUALS = 110,
-		GREATER_THAN = 111,
-		QUESTION = 112,
-		COMMERCIAL_AT = 113,
-		CARET = 114,
-		UNDERLINE = 115,
-		OPENING_BRACE = 116,
-		CLOSING_BRACE = 117,
-		TILDE = 118,
+		CLAMP_MSS = 57,
+		OPT_FRAGM = 58,
+		INVALID = 59,
+		NEW = 60,
+		ESTABLISHED = 61,
+		RELATED = 62,
+		M_STATE = 63,
+		MATCH_STATE = 64,
+		COMMA = 65,
+		M_MARK = 66,
+		MATCH_MARK = 67,
+		M_LIMIT = 68,
+		MATCH_LIMIT = 69,
+		MATCH_LIMIT_BURST = 70,
+		M_MPORT = 71,
+		MATCH_SRC_MULTIPORT = 72,
+		MATCH_SRC_MULTIPORT_SHORT = 73,
+		MATCH_DST_MULTIPORT = 74,
+		MATCH_DST_MULTIPORT_SHORT = 75,
+		MATCH_ICMP_TYPE = 76,
+		MATCH_SRC_PORT = 77,
+		MATCH_SRC_PORT_SHORT = 78,
+		MATCH_DST_PORT = 79,
+		MATCH_DST_PORT_SHORT = 80,
+		MATCH_SYN = 81,
+		SYN = 82,
+		ACK = 83,
+		FIN = 84,
+		RST = 85,
+		URG = 86,
+		PSH = 87,
+		ALL = 88,
+		NONE = 89,
+		MATCH_TCP_FLAGS = 90,
+		MATCH_TCP_OPTION = 91,
+		NUMBER = 92,
+		Whitespace = 93,
+		NEG_INT_CONST = 94,
+		HEXDIGIT = 95,
+		SECONDS = 96,
+		SET = 97,
+		RSOURCE = 98,
+		ULOG_QTHR = 99,
+		ULOG_NLG = 100,
+		ULOG_CPR = 101,
+		NUMBER_SIGN = 102,
+		PERCENT = 103,
+		AMPERSAND = 104,
+		APOSTROPHE = 105,
+		OPENING_PAREN = 106,
+		CLOSING_PAREN = 107,
+		PLUS = 108,
+		DOT = 109,
+		SEMICOLON = 110,
+		LESS_THAN = 111,
+		EQUALS = 112,
+		GREATER_THAN = 113,
+		QUESTION = 114,
+		COMMERCIAL_AT = 115,
+		CARET = 116,
+		UNDERLINE = 117,
+		OPENING_BRACE = 118,
+		CLOSING_BRACE = 119,
+		TILDE = 120,
 		NULL_TREE_LOOKAHEAD = 3
 	};
 #ifdef __cplusplus
