@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: pf.cpp,v 1.41 2007/12/14 07:07:16 vkurland Exp $
+  $Id: pf.cpp,v 1.43 2008/05/10 20:44:02 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -519,6 +519,11 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
             pf_file << endl;
         }
 
+
+        if ( ! options->getStr("pf_optimization").empty() )
+            pf_file << "set optimization "
+                    << options->getStr("pf_optimization") << endl;
+
         pf_file << printTimeout(options,
                                 "pf_do_timeout_interval","pf_timeout_interval",
                                 "interval");
@@ -576,12 +581,6 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                                 "pf_set_adaptive","pf_adaptive_end",
                                 "adaptive.end");
 
-
-
-        if ( ! options->getStr("pf_optimization").empty() )
-            pf_file << "set optimization "
-                    << options->getStr("pf_optimization") << endl;
-
         // check if any interface is marked as 'unprotected'
         // and generate 'set skip on <ifspec>' commands
 
@@ -792,16 +791,6 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
 
 	fw_file << endl;
 
-
-
-
-        fw_file << endl 
-                << "$PFCTL -d " << endl
-                << "$PFCTL -F nat" << endl
-                << "$PFCTL -F rules" << endl
-                << "$PFCTL -F Sources" << endl
-                << "$PFCTL -F Tables" << endl;
-
         if (prolog_place == "fw_file")
             printProlog(fw_file, pre_hook);
 
@@ -821,10 +810,6 @@ _("Dynamic interface %s should not have an IP address object attached to it. Thi
                     << " || exit 1"
                     << endl;
 
-	fw_file << "$PFCTL -e"
-                << " || exit 1"
-                << endl;
-        
         fw_file << endl;
         fw_file << "#" << endl;
         fw_file << "# Epilog script" << endl;
