@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf.h,v 1.6 2006/05/16 23:00:17 vkurland Exp $
+  $Id: NATCompiler_ipf.h,v 1.7 2007/10/07 01:21:07 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -33,6 +33,8 @@
 
 #define FTP_PORT    21
 #define RCMD_PORT   514
+#define KRCMD_PORT  544
+#define EKSHELL_PORT 2106
 #define H323_PORT   1720
 #define RAUDIO_PORT 5050
 #define ISAKMP_PORT 500
