@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_ipf_writers.cpp,v 1.4 2005/03/30 07:33:18 vkurland Exp $
+  $Id: NATCompiler_ipf_writers.cpp,v 1.5 2006/05/17 02:30:18 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -133,7 +133,7 @@ void NATCompiler_ipf::PrintRule::_printAddr_R_LB(RuleElementTDst *tdst)
     {
         FWObject *o= *i;
 	FWObject *obj = NULL;
-        if (FWReference::cast(o)!=NULL) obj=compiler->getCachedObj(o->getStr("ref"));
+        if (FWReference::cast(o)!=NULL) obj=FWReference::cast(o)->getPointer();
 
         Address *a=Address::cast(obj);
 
