@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: NATCompiler_pf.h,v 1.8 2006/06/22 05:04:16 vkurland Exp $
+  $Id: NATCompiler_pf.h,v 1.9 2007/06/21 03:25:45 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -218,7 +218,8 @@ namespace fwcompiler {
             std::string re_type;
             public:
             swapAddressTableObjectsInRE(const std::string &name,
-                      const std::string &t) : PolicyRuleProcessor(name) { re_type=t; }
+                      const std::string &t) : PolicyRuleProcessor(name)
+            { re_type=t; }
             virtual bool processNext();
         };
 
@@ -227,14 +228,24 @@ namespace fwcompiler {
         {
             public:
             swapAddressTableObjectsInOSrc(const std::string &n) :
-                swapAddressTableObjectsInRE(n,libfwbuilder::RuleElementOSrc::TYPENAME) {}
+                swapAddressTableObjectsInRE(n,
+                                  libfwbuilder::RuleElementOSrc::TYPENAME) {}
         };
 
         class swapAddressTableObjectsInODst : public swapAddressTableObjectsInRE
         {
             public:
             swapAddressTableObjectsInODst(const std::string &n) :
-                swapAddressTableObjectsInRE(n,libfwbuilder::RuleElementODst::TYPENAME) {}
+                swapAddressTableObjectsInRE(n,
+                                  libfwbuilder::RuleElementODst::TYPENAME) {}
+        };
+            
+        class swapAddressTableObjectsInTDst : public swapAddressTableObjectsInRE
+        {
+            public:
+            swapAddressTableObjectsInTDst(const std::string &n) :
+                swapAddressTableObjectsInRE(n,
+                                  libfwbuilder::RuleElementTDst::TYPENAME) {}
         };
             
         /**
@@ -250,23 +261,37 @@ namespace fwcompiler {
             std::string re_type;
             public:
             processMultiAddressObjectsInRE(const std::string &name,
-                      const std::string &t) : NATRuleProcessor(name) { re_type=t; }
+                      const std::string &t) : NATRuleProcessor(name)
+            { re_type=t; }
             virtual bool processNext();
         };
 
 
-        class processMultiAddressObjectsInOSrc : public processMultiAddressObjectsInRE
+        class processMultiAddressObjectsInOSrc :
+                  public processMultiAddressObjectsInRE
         {
             public:
             processMultiAddressObjectsInOSrc(const std::string &n) :
-                processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementOSrc::TYPENAME) {}
+                processMultiAddressObjectsInRE(n,
+                                 libfwbuilder::RuleElementOSrc::TYPENAME) {}
         };
 
-        class processMultiAddressObjectsInODst : public processMultiAddressObjectsInRE
+        class processMultiAddressObjectsInODst :
+                  public processMultiAddressObjectsInRE
         {
             public:
             processMultiAddressObjectsInODst(const std::string &n) :
-                processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementODst::TYPENAME) {}
+                processMultiAddressObjectsInRE(n,
+                                 libfwbuilder::RuleElementODst::TYPENAME) {}
+        };
+
+        class processMultiAddressObjectsInTDst :
+                  public processMultiAddressObjectsInRE
+        {
+            public:
+            processMultiAddressObjectsInTDst(const std::string &n) :
+                processMultiAddressObjectsInRE(n,
+                                 libfwbuilder::RuleElementTDst::TYPENAME) {}
         };
 
 
