@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_solaris.cpp,v 1.1.4.1 2006/03/19 06:08:18 vkurland Exp $
+  $Id: OSConfigurator_solaris.cpp,v 1.3 2006/03/19 06:35:00 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -215,8 +215,7 @@ void  OSConfigurator_solaris::configureInterfaces()
             Interface *iface=dynamic_cast<Interface*>(*i);
             assert(iface);
 
-            if (iface->isDyn()) continue;
-            if (iface->isUnnumbered()) continue;
+            if (!iface->isRegular()) continue;
 
             FWObjectTypedChildIterator j=iface->findByType(IPv4::TYPENAME);
             for ( ; j!=j.end(); ++j ) 
