@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf.cpp,v 1.10 2006/09/09 05:05:02 vkurland Exp $
+  $Id: PolicyCompiler_ipf.cpp,v 1.12 2007/05/08 02:11:39 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -137,6 +137,7 @@ bool PolicyCompiler_ipf::doSrcNegation::processNext()
     if (src->getNeg()) {
         RuleElementSrc *nsrc;
 	PolicyRule     *r;
+        FWOptions *ruleopt;
 
 	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
@@ -147,6 +148,8 @@ bool PolicyCompiler_ipf::doSrcNegation::processNext()
         nsrc->setNeg(false);
 	r->setBool("quick",false);
         r->setBool("skip_check_for_duplicates",true);
+        ruleopt = r->getOptionsObject();
+        ruleopt->setBool("stateless", true);
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
@@ -175,6 +178,7 @@ bool PolicyCompiler_ipf::doDstNegation::processNext()
     if (dst->getNeg()) {
         RuleElementDst *ndst;
 	PolicyRule     *r;
+        FWOptions *ruleopt;
 
 	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
 	compiler->temp_ruleset->add(r);
@@ -185,6 +189,8 @@ bool PolicyCompiler_ipf::doDstNegation::processNext()
         ndst->setNeg(false);
 	r->setBool("quick",false);
         r->setBool("skip_check_for_duplicates",true);
+        ruleopt = r->getOptionsObject();
+        ruleopt->setBool("stateless", true);
 	tmp_queue.push_back(r);
 
 	r= PolicyRule::cast(compiler->dbcopy->create(PolicyRule::TYPENAME) );
@@ -451,6 +457,9 @@ void PolicyCompiler_ipf::compile()
         add( new doDstNegation(               "process negation in Dst"                         ) );
         add( new doSrvNegation(               "process negation in Srv"                         ) );
         add( new ExpandGroups(                "expand groups"                                   ) );
+
+        add( new CheckForTCPEstablished("check for TCPService objects with flag \"established\"") );
+            
         add( new eliminateDuplicatesInSRC(    "eliminate duplicates in SRC"                     ) );
         add( new eliminateDuplicatesInDST(    "eliminate duplicates in DST"                     ) );
         add( new eliminateDuplicatesInSRV(    "eliminate duplicates in SRV"                     ) );
