@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf_writers.cpp,v 1.10 2007/04/03 16:14:36 vkurland Exp $
+  $Id: PolicyCompiler_ipf_writers.cpp,v 1.11 2007/05/08 00:22:58 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -382,7 +382,7 @@ bool PolicyCompiler_ipf::PrintRule::processNext()
     _printWith(srv);
 
 /* keeping state does not apply to deny/reject */
-    if ( ! ruleopt->getBool("stateless") && rule->getAction()==PolicyRule::Accept) 
+    if ( ! ruleopt->getBool("stateless") )
     {  
 /*
  * this is per advice from Darren Reed  http://false.net/ipfilter/2002_12/0176.html
