@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf.h,v 1.2 2005/04/04 07:00:55 vkurland Exp $
+  $Id: PolicyCompiler_pf.h,v 1.10 2006/06/17 21:53:54 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -29,6 +29,7 @@
 #include <fwbuilder/libfwbuilder-config.h>
 #include "fwcompiler/PolicyCompiler.h"
 
+#include "TableFactory.h"
 
 namespace libfwbuilder {
     class IPService;
@@ -41,6 +42,7 @@ namespace libfwbuilder {
     class IPv4;
 };
 
+
 namespace fwcompiler {
 
     class NATCompiler_pf;
@@ -60,9 +62,6 @@ namespace fwcompiler {
 
 	protected:
 
-        std::list<libfwbuilder::FWObject*> tables;
-
-
 	/**
 	 *   splits rule if one of the objects in Src * is firewall
 	 *   itself. This is needed to properly choose direction *
@@ -160,7 +159,76 @@ namespace fwcompiler {
 	 */
         DECLARE_POLICY_RULE_PROCESSOR(doSrvNegation);
 
-	/**
+
+        /**
+         * like standard processor swapMultiAddressObjectsInRE,
+         * but swaps compile-time address tables
+         *
+         * We need this because unlike on other platforms, we need to
+         * generate code for compile-time AddressTables using their
+         * object name (to name the table after that). This
+         * substantially complicates things, we have to register
+         * AddressTable objects with TableFactory and then replace
+         * them with corresponding run time objects. This is unique 
+         * feature of the compiler for PF.
+         */
+        class swapAddressTableObjectsInRE : public PolicyRuleProcessor
+        {
+            std::string re_type;
+            public:
+            swapAddressTableObjectsInRE(const std::string &name,
+                      const std::string &t) : PolicyRuleProcessor(name) { re_type=t; }
+            virtual bool processNext();
+        };
+
+
+        class swapAddressTableObjectsInSrc : public swapAddressTableObjectsInRE
+        {
+            public:
+            swapAddressTableObjectsInSrc(const std::string &n) :
+                swapAddressTableObjectsInRE(n,libfwbuilder::RuleElementSrc::TYPENAME) {}
+        };
+
+        class swapAddressTableObjectsInDst : public swapAddressTableObjectsInRE
+        {
+            public:
+            swapAddressTableObjectsInDst(const std::string &n) :
+                swapAddressTableObjectsInRE(n,libfwbuilder::RuleElementDst::TYPENAME) {}
+        };
+            
+        /**
+         * Split rule if MultiAddress object is used in RE to make
+         * sure it is single object. Also check for the case where
+         * MultiAddress object is used in combination with negation,
+         * this case is not supported. NOTE: this restriction can be
+         * removed if PF adds support for recursively defined tables
+         * (tables as elements inside tables).
+         */
+        class processMultiAddressObjectsInRE : public PolicyRuleProcessor
+        {
+            std::string re_type;
+            public:
+            processMultiAddressObjectsInRE(const std::string &name,
+                      const std::string &t) : PolicyRuleProcessor(name) { re_type=t; }
+            virtual bool processNext();
+        };
+
+
+        class processMultiAddressObjectsInSrc : public processMultiAddressObjectsInRE
+        {
+            public:
+            processMultiAddressObjectsInSrc(const std::string &n) :
+                processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementSrc::TYPENAME) {}
+        };
+
+        class processMultiAddressObjectsInDst : public processMultiAddressObjectsInRE
+        {
+            public:
+            processMultiAddressObjectsInDst(const std::string &n) :
+                processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementDst::TYPENAME) {}
+        };
+
+        /**
          * This is to work around a "feature" specific to PF: If NAT
          * policy defines a redirect rule (a rule which sends packets
          * to the firewall itself, possibly changing port numbers),
@@ -248,7 +316,6 @@ namespace fwcompiler {
         {
             void createTablesForRE(libfwbuilder::RuleElement *re,
                                    libfwbuilder::Rule        *rule);
-            libfwbuilder::FWObject* findTable(libfwbuilder::RuleElement *re);
             public:
             createTables(const std::string &name) : PolicyRuleProcessor(name) {}
             virtual bool processNext();
@@ -351,10 +418,13 @@ namespace fwcompiler {
             virtual void _printNegation(libfwbuilder::RuleElement  *o);
 
             virtual void _printAction(libfwbuilder::PolicyRule *r);
+            virtual void _printRouteOptions(libfwbuilder::PolicyRule *r);
             virtual void _printLogging(libfwbuilder::PolicyRule *r);
             virtual void _printDirection(libfwbuilder::PolicyRule *r);
             virtual void _printInterface(libfwbuilder::PolicyRule *r);
             virtual void _printLabel(libfwbuilder::PolicyRule *r);
+            virtual void _printQueue(libfwbuilder::PolicyRule *r);
+            virtual void _printTag(libfwbuilder::PolicyRule *r);
             virtual std::string _printLogPrefix(libfwbuilder::PolicyRule *r,const std::string &prefix);
 
             public:
@@ -371,9 +441,12 @@ namespace fwcompiler {
 	PolicyCompiler_pf(libfwbuilder::FWObjectDatabase *_db,
 			  const std::string &fwname,
 			  fwcompiler::OSConfigurator *_oscnf,
-                          NATCompiler_pf *_natcmp) : PolicyCompiler(_db,fwname,_oscnf) 
-        { natcmp=_natcmp;   }
-
+                          NATCompiler_pf *_natcmp,
+                          TableFactory *tbf = NULL) : PolicyCompiler(_db,fwname,_oscnf) 
+        {
+            natcmp=_natcmp;
+            tables = tbf;
+        }
 
 	virtual int  prolog();
 	virtual void compile();
@@ -381,6 +454,7 @@ namespace fwcompiler {
 
 	protected:
 
+        TableFactory           *tables;
         NATCompiler_pf         *natcmp;
 	libfwbuilder::IPv4     *loopback_address;
 
