@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: TableFactory.cpp,v 1.10 2006/09/09 05:05:03 vkurland Exp $
+  $Id: TableFactory.cpp,v 1.11 2006/10/07 05:49:05 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -175,9 +175,12 @@ string TableFactory::PrintTables()
         MultiAddressRunTime *atrt = MultiAddressRunTime::cast(grp);
         if (atrt!=NULL && atrt->getSubstitutionTypeName()==AddressTable::TYPENAME)
         {
-            output << "persist file \""
-                   << atrt->getSourceName()
-                   << "\"";
+            output << "persist";
+            if ( !atrt->getSourceName().empty() )
+                output << " file \""
+                       << atrt->getSourceName()
+                       << "\"";
+
             output << endl;
             continue;
         }
